/****************************************************************************

  module      : veo112c.cpp

  -------------------------------------------------------------------------

  responsible : FrankH

  special area: tool
  description : get first / last logpno from save


  last changed: 1999-03-24  16:54
  see also    : example.html ...

  -------------------------------------------------------------------------

  copyright:    Copyright by SAP AG, 1998



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

*****************************************************************************/

#include <stdlib.h>
#include <stdio.h>

#include "gsp00.h"
#include "ggg00.h"
#include "gsp05.h"
#include "geo60.h"
#include "heo06.h"
#include "gkb03.h"

#ifdef WIN32
#include <windows.h>
#endif

#define MOD__ "veo112c.cpp:"
#undef MF__

#ifndef TRUE
#define TRUE   1
#define FALSE  0
#endif /* FALSE */

externC void sqlinit             ( char *                  psComponent,
                                   tsp00_BoolAddr          pbCancelAddress );

externC void sqlfinish           ( tsp00_Bool              bTerminate );


#define IS_FIRST_INFO_PAGE(_page )  ( _page->inf_pt2 == pt2VolumeFirstInfo_egg00 && \
                                      _page->inf_pt  == ptSave_egg00 )

#define IS_DATA_PAGE(_page )  ( _page->inf_pt == ptData_egg00 || _page->inf_pt == ptLog_egg00 )
/* !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! */

#define ERRTEXT(v,t)  { DBG3((MF__,t));\
		      v.rawAssign(t); }

static char BAD_BLOCKSIZE_GIVEN []            = "bad blocksize given";
static char BAD_BLOCKSIZE_READ  []            = "bad blocksize read";



static int	sqlextract_logpno ( tsp_vfilename                   SaveFile ,
                                tsp_int2                        BufCnt ,
                                char                            FirstLast,
                                tsp00_VfReturn_Enum           * error ,
                                tsp00_ErrText                 & errtext ) ;


int	main ( int argc , char **argv )
{
  #undef  MF__
  #define MF__ MOD__"main"
    tsp00_ErrTextc              errtextc;
    tsp_vfilename               SaveFile ;
    tsp00_VfReturn_Enum         error ;
    tsp00_ErrText               errtext ;
    tsp_int2                    BufCnt ;
	int                         LogPno ;
    char                        WhichLpno ;


    if (  argc != 4 || 
		 ( (WhichLpno = *(argv[3])) != 'f' && WhichLpno != 'l') )
    {
	(void) fputs ( "usage: g_fl_lpno savefile blck_cnt f|l\n", stderr );
	return ( 1 );
    }

    strcpy(SaveFile,argv[1]) ;

    BufCnt = atoi ( argv[2] ) ;

    sqlinit ( (char *)"g_fl_lpno" , (tsp00_BoolAddr)0 );
    LogPno = sqlextract_logpno ( SaveFile, BufCnt, WhichLpno, &error, errtext ) ;
    if ( error != vf_ok )
      { errtextc.p2c( errtext );
        fprintf ( stderr, "g_fl_lpno: %s \n" , (char *) errtextc ) ;
      }
    else
       fprintf ( stdout, "%d\n", LogPno );

    sqlfinish ( FALSE );
    return ( error != vf_ok );
}




static int	sqlextract_logpno ( tsp_vfilename                   SaveFile ,
                                tsp_int2                        BufCnt ,
                                char                            FirstLast,
                                tsp00_VfReturn_Enum           * error ,
                                tsp00_ErrText                 & errtext )
{
  #undef  MF__
  #define MF__ MOD__"sqlextract_logpno"

  tsp_int4             PoolName = 0;
  tsp_int4             SaveFileNo,
                       RecLen = BufCnt * sizeof(tsp00_Page); /* XXX rdependend on tsp00_Page. Better retry sqlfsaveopenc() with the returned RecLen... */

  tsp_longint          BytesRead ;
  char                 *Buf = NULL ;
  tsp5_rte_fileerror   RteError ;
  int                  LogPno =-1 ;
  tkb3_info_stuff      *InfoPage ;
  
  DBGIN;

  DBG3 ((MF__, "SaveFile = %s"  , SaveFile )) ;
  DBG3 ((MF__, "BufCnt   = %d"  , BufCnt   )) ;
  DBG3 ((MF__, "FirstLast= %c\n", FirstLast   )) ;

  if ( BufCnt < 1 )
    { *error = vf_notok  ;
       ERRTEXT( errtext, BAD_BLOCKSIZE_GIVEN );
    }
  else
      *error = vf_ok  ;

  if ( *error == vf_ok )
    { sqlfsaveopenc ( SaveFile, SP5VF_READ, &RecLen, &SaveFileNo, (void**) &Buf, &RteError ) ;
      if ( ( *error = RteError.sp5fe_result ) != vf_ok )
        ERRTEXT( errtext, RteError.sp5fe_text )
    }

  if ( *error == vf_ok )
    { 
      do
      {
        sqlfreadc ( SaveFileNo, Buf, RecLen, &BytesRead , &RteError ) ;

        DBG3 ((MF__, " %8d.sqlfread : %d Bytes", ++TotalReads, BytesRead )) ;

        if ( ( *error = RteError.sp5fe_result ) == vf_ok && BytesRead > 0 )
        { InfoPage = (tkb3_info_stuff *) Buf ;
          if ( IS_FIRST_INFO_PAGE ( InfoPage ) ) 
            {
		      LogPno = FirstLast == 'f' ? InfoPage->inf_first_lpno 
			                            : InfoPage->inf_last_lpno ;
            }
	    }
        else
          if ( *error != vf_ok )
            ERRTEXT( errtext, RteError.sp5fe_text )
          else
            { *error = vf_notok ;
              ERRTEXT( errtext, BAD_BLOCKSIZE_READ );
            }
        }
      while ( *error == vf_ok && !IS_DATA_PAGE( InfoPage ) && LogPno == -1 ) ;
    }

  sqlfclosec ( SaveFileNo, SP5VF_CLOSE_NORMAL, &RteError);

  DBGOUT ;
  return( LogPno ) ;
}

