#!/usr/bin/perl

# This script invokes 'stedi', the 'SQL Test Editor'.
#
# Before doing so, it performs various tests on the environment and command 
# line arguments. 
# 
# Changes:
#	
# date	     version	author		comment
# 2002-07-26 1.0	Dennis		Initial Version
# 2002-07-29 1.1	Paul		Try to guess JTEST_ROOT according to this
#					script's location. 
# 2002-07-31 1.2	Paul		Fixed bug: Pass -Djtest.root=... to Java. 

use Getopt::Long;
use File::Basename;
use Cwd;
use File::Spec;

$version = "1.2";

print "stedi.pl $version\n";

###############################################################################
# Parse commandline options.
###############################################################################
%options = ();

if(! &GetOptions(	\%options,
			'h|help|?',			
		) ) {
			
		
		print "run \'stedi.pl --help\' for help";
		exit(1);						
}

$classpathsep = $^O =~ /mswin/i ? ";" : ":";
$pathsep = $^O =~ /mswin/i ? "\\" : "/";

$jtest_root = $ENV{"JTEST_ROOT"};

if(!$jtest_root) {	
	
	# Try to guess JTEST_ROOT from this script's location.
	
	# Change current working directory according to the directory part of the script's
	# relative (to the perl interpreter's cwd) location. 
	#
	# A change of the cwd is not needed for operating, but this is most simple and safe way to 'calculate'  
	# the script's absolute location, I can think of.
	# 
	chdir dirname($0);
		
	# Now this is our guess. By doing a cwd I don't have to deal with platform specific annoyances or
	# strange relative locations. As long as perl's chdir, dirname and cwd do well.
	$jtest_root = cwd();
				
	print	"Environment variable JTEST_ROOT is missing.\n\n" .	
		"JTEST_ROOT should point to the base directory of the testframe environment.\n" .
		"This is the place where 'jtrun.pl' is located.\n";
	
	print 	"\nTrying to work with educated guess based on this script's location:\n$jtest_root\n";
	
	# At least $jtest_root/frame is needed. If it's not there, guessing failed.	
	if(! -d File::Spec->catfile($jtest_root, 'frame')) {
		print "Subdirectory 'frame' does not exists. Giving up.\n\nPlease move stedi.pl to JTEST_ROOT or set environment variable JTEST_ROOT accordingly.\n";
		exit(1);					
	}	
		
}

@jtest_dirs = ( $jtest_root, "$jtest_root" . $pathsep . "frame", "$jtest_root" . $pathsep . "tests", "$jtest_root" . $pathsep . "protocols", "$jtest_root" . $pathsep . "lib" );

$classpath = 	"$jtest_root" . $pathsep . "tests" . $classpathsep .
		"$jtest_root" . $pathsep . "frame" . $classpathsep .
		"$jtest_root" . $pathsep . "lib";
		
# Append all *.jar files in the jtest/tests directory.		
		
opendir TESTDIR, "$jtest_root" . $pathsep . "tests";
@testdir_files = grep /.*jar/, readdir TESTDIR;
closedir TESTDIR;

foreach $jar (@testdir_files) {
	$classpath .= $classpathsep . "$jtest_root" . $pathsep . "tests" . $pathsep . "$jar";		
}

# Append all *.jar files in the jtest/frame directory.

opendir FRAMEDIR, "$jtest_root" . $pathsep . "frame";
@framedir_files = grep /.*jar/, readdir FRAMEDIR;
closedir FRAMEDIR;

foreach $jar (@framedir_files) {
	$classpath .= $classpathsep . "$jtest_root" . $pathsep . "frame" . $pathsep . "$jar";			
}

# Append all *.jar files in the jtest/lib directory.

opendir LIBDIR, "$jtest_root" . $pathsep . "lib";
@libdir_files = grep /.*jar/, readdir LIBDIR;
closedir LIBDIR;

foreach $jar (@libdir_files) {
	$classpath .= $classpathsep . "$jtest_root" . $pathsep . "lib" . $pathsep . "$jar";			
}

# Build list of properties to be passed to the Java VM via -D.
$javaproperties =  "-Djtest.root=\"$jtest_root\"";

# Main class of this application.
$mainclass = "com.sap.sapdb.testframe.gui.TestCaseInterpreter";

# Command line to execute.
$cmd = "java -classpath $classpath $javaproperties $mainclass ";

exit(system($cmd));