#  module      : installdb.py
#
#  responsible : d033893 
#
#  special area: SAP DB Manager
#
#  description : installation of database via DB Manager
#
#  prerequisite: Please install the dbm Scripting Interface.
#
#  remarks:      For including a private configuration this script
#                looks for a file named "myparams.dbm" in the current
#                directory. In this file you can provide private
#                definitions of parameters and devspaces.
#
#                Lines starting with "param_put" contains a valid
#                "param_put" DBMServer command.
#                This lines will be used in the "Create param file..."
#                section of this script.
#
#                Lines starting with "param_adddevspace" contains a
#                a valid "param_adddevspace" DBMServer command.                definition. Use format from the DBMServer command
#                This lines will be used in the "Add devspaces..."
#                section of this script.
#
#                All other lines will be ignored.
#
#    ========== licence begin  GPL
#    Copyright (C) 2001 SAP AG
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#    ========== licence end
#

import sys
import time
import os
import optlib
import socket
#strings
import string
import re
import regsub
#sapdb
from sapdb import dbm,loader,sql

def _options ():
    return [
    ('z', 'debug'            , ':', 'false'                 , 'specifies debug  mode'),                 # TRUE, FALSE
    ('n', 'node'             , ':', socket.gethostname()    , 'specifies servernode'),
    ('r', 'instroot'         , ':', ''                      , 'specifies INSTROOT path'),
    ('j', 'indepdatapath'    , ':', ' '                     , 'specifies indepdatapath'), 
    ('d', 'dbname'           , ':', 'sourcedb'              , 'specifies sapdb to create'),
    ('a', 'dbaUser'          , ':', 'DBA,DBA'               , 'specifies sapdb sysdba user'),
    ('c', 'charencoding'     , ':', 'ascii'                 , 'specifies sapdb char encoding'),         # ASCII , UNICODE
    ('o', 'osUser'           , ':', ''                      , 'specifies operating system user'),
    ('m', 'dbmUser'          , ':', 'DBM,DBM'               , 'specifies dbmserver user'),
    ('p', 'paramfile'        , ':', 'myparams.dbm'          , 'specifies a private param file'),
    ('b', 'restore'          , ':', None                    , 'restore database'),
]

def check_options(options):
    rc    = 0 
    
    options.debug        = string.upper(options.debug)
    options.charencoding = string.upper(options.charencoding)
    options.node         = string.upper(options.node)
    options.instroot     = string.upper(options.instroot)
    options.dbname       = string.upper(options.dbname)
    options.osUser       = string.upper(options.osUser)
    options.dbmUser      = string.upper(options.dbmUser)
    options.dbaUser      = string.upper(options.dbaUser)
    
    try:
        session = dbm.DBM ('',options.dbname, options.instroot, options.dbmUser )
        options.indepdatapath = session.cmd('dbm_getpath IndepDataPath ')
    except dbm.CommunicationError, err :
        print 'command failed:', err
    options.indepdatapath = regsub.split(options.indepdatapath,'\n')[0]
    
    #Transformation Resources
    print 'node            -n %s'  % options.node 
    print 'instroot        -r %s'  % options.instroot
    print 'indepdatapath   -j %s'  % options.indepdatapath
    print 'dbname          -d %s'  % options.dbname
    print 'dbaUser         -a %s'  % options.dbaUser     
    print 'osUser          -o %s'  % options.osUser       
    print 'dbmUser         -m %s'  % options.dbmUser      
    print 'charencoding    -c %s'  % options.charencoding
    print ''

def main (options, args):
   
    check_options(options) 
    
    dbname = options.dbname
    
    if os.name == 'posix' :
       options.osUser = 'remuser,Remuser'
    
    protfile =  os.path.join(options.instroot,  'wrk', 'install.prt' )
    
    open (protfile, 'a+')
    
    try:
       if options.debug == 'TRUE':
          input ('Remove    Databasesystem %s'   % options.dbname )
       if options.debug == 'FALSE':
          print 'Remove    Databasesystem %s'  % options.dbname 
          i = 1/0
    except:
        pass
   
    removeDB (options) 
   
    try:
       if options.debug == 'TRUE':
          input ('Install   Databasesystem %s' % options.dbname )
       if options.debug == 'FALSE':
          print 'Install   Databasesystem %s' % options.dbname  
          i = 1/0
    except:
        pass
   
    createDB(options)
    backupDB(options)                            
       
    if options.restore <> None: 
       restoreDB(options)   

def fatalError (msg):
    sys.stderr.write ('\ninstalldb.py: ' + msg + '\n')
    sys.exit (3)

def show (options,comment):
    if comment:
       if options.debug == 'TRUE': 
          print '%-30s' % (comment + '...'),

def getLines (fname):
    result = []
    if os.path.exists (fname):
        data = open (fname, 'r').read ()
        result = string.split (data, '\n')
    return result

def dbmcmd ( options, session, cmd, comment = None):
    protfile =  os.path.join(options.instroot,  'wrk', 'install.prt' )
    log = open ( protfile, 'a')
    try:
        log.write (cmd + '\n')
        try:
            show (options,comment)
            result = session.cmd (cmd)
            log.write ('//' + result + '\n')
            if comment:
               if options.debug == 'TRUE': 
                  print 'OK'
        except dbm.DBMServError, err:
            log.write (str (err.additionalInfo) + '\n')
            fatalError ('ERR at DBMServer command ' + cmd + ': ' + str (err.additionalInfo))
    finally:
        log.close ()
    return result

def dbm2cmd (session, comment, *cmds):
    show (comment)
    for cmd in cmds:
        dbmcmd ( options, session, cmd)
    if options.debug == 'TRUE':     
       print 'OK'

def checkVersion (session, options):
    show (options, 'Checking  version')
    versionString = dbmcmd ( options, session, 'version') #dbm_version
    match = re.search ('"(\d+)[.](\d+)[.](\d+)"', versionString)
    version = tuple (map (int, match.group (1, 2, 3)))
    if version < (7, 1, 3):
        fatalError ('ERR  Sorry, no support for version %d.%d.%d' % version)
    if options.debug == 'TRUE':     
       print 'OK'
    return version

def removeDB (options):
    try:
        session = dbm.DBM (options.node, options.dbname, '', options.dbmUser)
        dbmcmd ( options, session, 'db_stop'   , 'Stop      DB')
        dbmcmd ( options, session, 'db_drop'   , 'Drop      DB')
    except dbm.CommunicationError, err :
        print err
        
def createDB (options):
    session = dbm.DBM (options.node, '', options.instroot)
    version = checkVersion (session, options)
    dbmcmd ( options, session, 'db_create %s %s %s' % (options.dbname, options.dbmUser, options.osUser), 'Create    DB')
    if version < (7, 2, 0):
        session = dbm.DBM (options.node, options.dbname, '', options.dbmUser)

    localParams = getLines (options.paramfile)

    dbmcmd ( options, session, 'param_startsession',                 'Start     Session')
    dbmcmd ( options, session, 'param_init '                       , 'Init      Param'  )
    dbmcmd ( options, session, 'param_put MAXUSERTASKS  10'        , 'Put       Param'  )
    #dbmcmd( options, session, 'param_put CACHE_SIZE  3000'        , 'Put       Param'  )
    #dbmcmd( options, session, 'param_put FORMAT_DATAVOLUME NO   ' , 'Put       Param'  )


    if  (string.upper(options.charencoding[0:5]) == 'ASCII'   ) :
         dbmcmd ( options, session, 'param_put _UNICODE     NO'         , 'Put       Param Unicode No'   )
         dbmcmd ( options, session, 'param_put DEFAULT_CODE ASCII'      , 'Put       Param DefaultCode'  ) 
                     
    if  (string.upper(options.charencoding[0:7]) == 'UNICODE' ) :
         dbmcmd ( options, session, 'param_put _UNICODE     YES'        , 'Put       Param Unicode Yes'  )
         dbmcmd ( options, session, 'param_put DEFAULT_CODE UNICODE'    , 'Put       Param DefaultCode'  )
         
    # using myparams.dbm
    for line in localParams:
        if line [:9] == 'param_put':
            dbmcmd ( options, session, line)

    dbmcmd ( options, session, "param_checkall");
    dbmcmd ( options, session, "param_commitsession");

    if version < (7, 4, 0):
        dbmcmd ( options, session, 'param_adddevspace 1 SYS  sys_001  F'       ,'Add       SYS  Devspace')
    dbmcmd ( options, session,     'param_adddevspace 1 LOG  LOG_001  F 3000 ' ,'Add       LOG  Devspace');
    dbmcmd ( options, session,     'param_adddevspace 1 DATA DAT_001  F 12000 ','Add       DATA Devspace');
    for line in localParams:
        if line [:len ('param_adddevspace')] == 'param_adddevspace':
            dbmcmd ( options, session, line)

    if version < (7, 4, 4):
       dbmcmd ( options,  session, 'db_reg   -f'   ,                              'Register  Fast')
       dbmcmd ( options,  session, 'db_start -fast',                              'Start     Offline')
       #dbmcmd( options,  session, 'db_reg   -s'   ,                              'Register  Slow')
       #dbmcmd( options,  session, 'db_start -slow',                              'Start     Offline')
       dbmcmd ( options,  session, 'util_connect')
       dbmcmd ( options,  session, 'util_execute INIT CONFIG',                    'Init      Configuration')
       dbmcmd ( options,  session, 'util_activate %s' % (options.dbaUser ),       'Activate  DB')
       dbmcmd ( options,  session, 'util_release')
    
    if version >= (7, 4, 4):
       dbmcmd ( options,  session, 'db_reg   -f'   ,                              'Register  Fast')
       dbmcmd ( options,  session, 'db_start -fast',                              'Start     Offline')
       dbmcmd ( options,  session, 'db_activate %s'   % (options.dbaUser ),       'Activate DB')
    
    dbmcmd    ( options,  session, 'load_systab  -u %s -ud domp'    % (options.dbaUser),                          'Load      Systemtables')
    dbmcmd    ( options,  session, 'dbm_configset -raw NSR_ENV %s ' % (os.path.join(options.instroot,'nsr.txt')), 'Set       Configuration NSR')
    #dbmcmd   ( options,  session, 'util_execute diagnose switch layer \'kb\' debug \'kg\'' , 'Vtrace On')

    if version < (7, 2, 0):
        dbm2cmd (session, 'Restart serverdb', 'db_restart')
        
        
def backupDB(options):
    session = dbm.DBM (options.node, options.dbname, options.instroot)
    version = checkVersion (session, options)
    
    if version > (7, 4, 3):
       backupdata  = '%s_'    % os.path.join(options.instroot,  'wrk', options.dbname , 'LOADER', options.dbname)
       backuplog   = '%slog_' % os.path.join(options.instroot,  'wrk', options.dbname , 'LOADER', options.dbname)
    if version <= (7, 4, 3):
       backupdata  = '%s_'    % os.path.join(options.instroot, 'wrk', options.dbname)
       backuplog   = '%slog_' % os.path.join(options.instroot, 'wrk', options.dbname)
       restoredata = '%s_'    % os.path.join(options.instroot, 'wrk', options.dbname)
    
    if  os.path.isfile(backupdata):
        os.unlink(backupdata)
    if  os.path.isfile(backuplog):
        os.unlink(backuplog)
        
    dbmcmd ( options,  session, 'user_logon %s '                % (options.dbmUser),                                   'Logon     DBM' ) 
    dbmcmd ( options,  session, 'medium_put %slog %s FILE LOG'  % (options.dbname,backuplog),                          'Put       LOG  Medium')
    dbmcmd ( options,  session, 'medium_put %s    %s FILE DATA' % (options.dbname,backupdata),                         'Put       DATA Medium ')
    dbmcmd ( options,  session, 'util_connect',                                                                        'Connect   Utility')
    dbmcmd ( options,  session, 'backup_start %s'               % (options.dbname),                                    'Start     Backup')
    dbmcmd ( options,  session, 'autolog_on %slog '             % (options.dbname),                                    'AutoLog   On ')
    dbmcmd ( options,  session, 'util_release',                                                                        'Release   Utility')        
        
def restoreDB(options):
    session = dbm.DBM (options.node, '', options.instroot)
    version = checkVersion (session, options)
    
    if version > (7, 4, 3):
       backupdata  = '%s_'    % os.path.join (options.instroot, 'wrk', options.dbname, 'LOADER', options.dbname)
       backuplog   = '%slog_' % os.path.join (options.instroot, 'wrk', options.dbname, 'LOADER', options.dbname)
       restoredata = '%s_'    % os.path.join (options.instroot, 'wrk', options.dbname, 'LOADER', options.dbname)
    if version <= (7, 4, 3):
       backupdata  = '%s_'    % os.path.join (options.instroot, 'wrk', options.dbname)
       backuplog   = '%slog_' % os.path.join (options.instroot, 'wrk', options.dbname)
       restoredata = '%s_'    % os.path.join (options.instroot, 'wrk', options.dbname) 
           
    if  os.path.isfile(backupdata):
        os.unlink(backupdata)
    if  os.path.isfile(backuplog):
        os.unlink(backuplog)
        
    dbmcmd ( options,  session, 'db_create %s %s %s' % (options.dbname, options.dbmUser, options.osUser),              'Create    DB')
    dbmcmd ( options,  session, 'db_reg   -f',                                                                         'Register  Fast')
    dbmcmd ( options,  session, 'backup_media_put data %s FILE DATA' % ( restoredata ),                                'Put       DATA Medium ')   
    dbmcmd ( options,  session, 'service_connect')
    dbmcmd ( options,  session, 'backup_restore_config data',                                                          'Restore   Backup')
    dbmcmd ( options,  session, 'param_startsession ')
    dbmcmd ( options,  session, 'param_put rundirectory %s' % os.path.join(options.instroot,  'wrk', options.dbname),  'Put       Param RunDir' ) 
    dbmcmd ( options,  session, 'param_checkall ')
    dbmcmd ( options,  session, 'param_commitsession')
    dbmcmd ( options,  session, 'service_release')
    dbmcmd ( options,  session, 'db_cold  -f',                                                                         'Start     Offline')
    dbmcmd ( options,  session, 'util_connect')
    dbmcmd ( options,  session, 'util_execute INIT CONFIG',                                                            'Init      Configuration')
    dbmcmd ( options,  session, 'util_release')
    dbmcmd ( options,  session, 'util_connect')
    dbmcmd ( options,  session, 'recover_start data DATA',                                                             'Start     Recovery') 
    dbmcmd ( options,  session, 'util_release')
    dbmcmd ( options,  session, 'db_warm',                                                                             'Start     Online') 
    dbmcmd ( options,  session, 'medium_put %slog %s FILE LOG'  % (options.dbname,backuplog),                          'Put       LOG  Medium')
    dbmcmd ( options,  session, 'medium_put %s    %s FILE DATA' % (options.dbname,backupdata),                         'Put       DATA Medium ')
    dbmcmd ( options,  session, 'util_connect')
    dbmcmd ( options,  session, 'backup_start %s'               % (options.dbname),                                    'Start     Backup')
    dbmcmd ( options,  session, 'autolog_on %slog '             % (options.dbname),                                    'AutoLog   On ')
    dbmcmd ( options,  session, 'util_release')
    dbmcmd ( options,  session, 'load_systab -u %s -ud domp'    % (options.dbaUser),                                   'Load      Systemtables')
        
if __name__ == '__main__':
    optlib.optMain2 (main, _options ())
