#    module      : loadertest.py
#
#    responsible : d033893 
#
#    special area: SAP DB LOADER
#
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#

# usage 1:  %JTEST_ROOT%               >perl     jtrun.pl -R %INSTROOT% -d LO743 loadertest.cfg
# usage 2:  %JTEST_ROOT%\loader\python >x_python                                 loadertest.py 

#system
import sys
import time
import os
import socket
#shell
import shutil
#string
import string
import re
import regsub
#sapdb
import optlib
from   sapdb import dbm,loader,sql


loadersyntax = [
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'|                                        SAP DB Loader Session Attributes                                                             |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'|  Session Attribute       Attribute Value                                 Default Value                                              |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |', 
'|  SET COMPRESSED          \'/<s>/<d>/\'                                   \'/,/"/\'                                                  |',
'|  SET BLOBMASK            \'#######\'                                                                                                |',
'|  SQLMODE                 [INTERNAL|ANSI|DB2|ORACLE]                      INTERNAL                                                   |', 
'|  SET LANGUAGE            [ENG|DEU]                                       \'ENG\'                                                    |', 
'|  SET CODETYPE            [ASCII|UCS2|UTF8]                               ASCII                                                      |',
'|  SET CODEPAGE            [http://www.unicode.org/Public/MAPPINGS/]       ISO-8859-1                                                 |',
'|  SET DATE                [INTERNAL|ISO|USA|EUR|JIS]                      ISO                                                        |',
'|  SET TIME                [INTERNAL|ISO|USA|EUR|JIS]                      ISO                                                        |',
'|  SET TIMESTAMP           [INTERNAL|ISO|USA|EUR|JIS]                      ISO                                                        |',
'|  SET DECIMAL             \'/[<t>]/<d>/\'                                 \'//./\'                                                   |',
'|  SET BOOLEAN                                                             \'TRUE/FALSE\'                                             |',
'|  SET NULL                                                                \'?                   \'                                   |',
'|  SET TRANSACTION SIZE                                                    1000                                                       |',
'|  SET MAXERRORCOUNT                                                       100                                                        |',
'|  SET BACKUPTOOL          [TSM|NETWORKER|BACKINT]                         NETWORKER                                                  |', 
'|  SET ODBCTRACE           [ON|OFF]                                        OFF                                                        |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'|                                        SAP DB Loader Transformation Attributes                                                      |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                    |                    |                 |                |               |                       |                |',
'| What should be     | Transformation of  |  Logging of     | Package of     | Medium of     | Format of             | Mapping of     |',
'| imported/exported ?| Models und Data    |  Transformation | Transformation | Staging Area  | Models and Data       | Char Codetypes |',
'|                    |                    |                 |                |               |                       |                |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|Catalog, Data and   |EXTRACT|LOAD        |                 | DB             |               |                       |                |',
'|Package of a        |CONFIGURATION       |                 |                | FILE          | DTL, XMI              | UCS2           |',
'|Database            |CATALOG             |                 |                | PIPE          | DDL, XMI              | UTF8           |',
'|                    |DATA                |                 |                | TAPE          | PAGES, RECORDS        | ASCII          |',
'|                    |PACKAGE             |[RESTART]        |                |               | DTL, XMI              |                |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|Catalog, Data and   |EXTRACT|LOAD        |                 | USER           |               |                       |                |',
'|Package of a        |CONFIGURATION       |                 |                | FILE          | DTL, XMI              | UCS2           |',
'|Database User       |CATALOG             |                 |                | PIPE          | DDL, XMI              | UTF8           |',
'|                    |DATA                |                 |                | TAPE          | PAGES, RECORDS        | ASCII          |',
'|                    |PACKAGE             |[RESTART]        |                |               | DTL, XMI              |                |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|Catalog, Data and   |EXTRACT|LOAD[FAST]| |                 | TABLE          |               |                       |                |',
'|Package of a        |CONFIGURATION       |                 |                | FILE          | DTL, XMI              | UCS2           |',
'|Database Table      |CATALOG             |                 |                | PIPE          | DDL, XMI              | UTF8           |',
'|                    |DATA                |                 |                | TAPE          | PAGES, RECORDS,       | ASCII          |',
'|                    |                    |                 |                |               | FORMATTED, COMPRESSED |                |',
'|                    |                    |                 |                |               | COMPRESSED            |                |',
'|                    |PACKAGE             |[RESTART]        |                |               | DTL, XMI              |                |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|Data and Package    |EXTRACT|LOAD[FAST]  |                 | COLUMNS FIELDS |               |                       |                |',
'|of a qualified      |                    |                 |                | FILE          |                       | UCS2           |',
'|Database Columnset  |                    |                 |                | PIPE          |                       | UTF8           |',
'|                    |DATA                |                 |                | TAPE          | FORMATTED, COMPRESSED | ASCII          |',
'|                    |PACKAGE             |[RESTART]        |                |               | DTL, XMI              |                |',
'|                    |                    |                 |                |               |                       |                |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'|                                        SAP DB Loader Migration Attributes                                                           |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'| Option     Transformation Attribute                 Attribute Value                 Default Value             Varname               |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'| t          Type      of Transformation              TRANSPORT, EXPORT, IMPORT       TRANSPORT                 transformationtype    |',
'| p          Package   of Transformation              DB  , USER, TABLE               DB                        transformationpackage |',
'| m          Medium    of Staging Area                PIPE, FILE, TAPE                FILE                      streammedium          |',
'| f          Format    of Models and Data             DDL, XML                        DDL,RECORDS               streamformat          |',
'|                                                     RECORDS, PAGES,                                                                 |',
'|                                                     COMPRESSED, FORMATTED                                                           |',
'| F                                                   DATA , FAST                     DATA                      streamformat_target   |',
'| e          Mapping of Char Codetypes                ASCII, UCS2, UTF8               ASCII                     streamcharencoding    |',
'| b          Mask    of BLOB Datatypes                SINGLE, MULTIPLE                SINGLE                    streamblob            |',
'| l          Logging of Transformation                START, RESTART                  START                     restart               |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'| x          Connector to Medium                      PIPE2TAPE,PIPE2FILE,PIPE2HTTP   none                      streamconnector       |',
'| X          Connector to Database System             SAPDB, ADABAS                   SAPDB                     migration             |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'| z          specifies debug  mode                    TRUE , FALSE                    false                     debug                 |',
'| t          specifies test   case                                                    80                        testcase              |',
'|                                                                                                                                     |',
'| n          specifies source servernode                                              localhost                 sourcenode            |',
'| r          specifies sapdb  source  instroot                                        os.environ[INSTROOT]      sourceinstroot        |',
'| i          init      sapdb  source                  SYSTEM,USER,CATALOG,DELETE      data                      sourceinit            |',
'| d          specifies source serverdb to create                                      sourcedb                  sourcedbname          |',
'| a          specifies source SYSDBA user                                             DBA                       sourcedbauser         |',
'| c          specifies source catalog coding          ASCII, UNICODE                  ascii                     sourcecatalog         |',
'|                                                                                                                                     |',
'| N          specifies target servernode                                              localhost                 targetnode            |',
'| R          specifies sapdb  target  instroot                                        os.environ[INSTROOT]      targetinstroot        |',
'| I          init      sapdb  target                  SYSTEM,USER,CATALOG,DELETE      system                    targetinit            |',
'| D          specifies target serverdb to create                                      targetdb                  targetdbname          |',
'| A          specifies target SYSDBA user                                             DBA                       targetdbauser         |',
'| C          specifies target catalog coding          ASCII, UNICODE                  ascii                     targetcatalog         |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
'|                                                                                                                                     |',
'|                                        SAP DB Loader Migration Parameters                                                           |',
'|                                                                                                                                     |',
'|-------------------------------------------------------------------------------------------------------------------------------------|',
]

#package webdav : 1,2,3,4,5
#medium  file   : 6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57                                                                                                                                                                                            
#medium  pipe   : 58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82                                                                                                                                                                                                            
#medium  tape   : 83,84,85 

parameters = [
# |Transformation                 |Datastream                                                                |Testframe                                 |Initialize DB                                                                                         
                                                                                                                                                                                                                                                              
# |Type        |Package  |Logging |Medium |Format              |Encoding                       |Blobmask     |Case |Validation                |Debug    |Sourcedb             |Version                        |Targetdb               |Version                                                                               
# |1           |2        |3       |4      |5            |6     |7       |8         |9          |10           |11   |12        |13             |14       |15        |16        |17                |18          |19        |20          |21               |22                                                                  

#data                                     usecases:dav
 '-t TRANSPORT -p WEBDAV -l START -m FILE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u  1 -v data    -V complete     -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                        
 '-t TRANSPORT -p WEBDAV -l START -m FILE -f RECORDS    -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u  2 -v data    -V complete     -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p WEBDAV -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u  3 -v data    -V complete     -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p WEBDAV -l START -m FILE -f COMPRESSED -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u  4 -v data    -V complete     -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p WEBDAV -l START -m FILE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u  5 -v data    -V complete     -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
#metadata                                 usecases : ASCII2ASCII
 '-t TRANSPORT -p DB     -l START -m FILE -f DDL        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u  6 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p DB     -l START -m FILE -f XML        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u  7 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m FILE -f DDL        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u  8 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m FILE -f XML        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u  9 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f DDL        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 10 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f XML        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 11 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 12 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 13 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 14 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                         
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 15 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
#data
 '-t TRANSPORT -p DB     -l START -m FILE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 16 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p DB     -l START -m FILE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 17 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m FILE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 18 -v data    -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m FILE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 19 -v data    -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 20 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 21 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 22 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 23 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F DATA -e ASCII -c ASCII   -C ASCII   -b MULTIPLE   -u 24 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C ASCII   -b MULTIPLE   -u 25 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
#metadata                                 usecases : ASCII2UNICODE
 '-t TRANSPORT -p DB     -l START -m FILE -f DDL        -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 26 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 27 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 28 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
#data
 '-t TRANSPORT -p DB     -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u 29 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u 30 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u 31 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 32 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 33 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 34 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 35 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F DATA -e UTF8  -c ASCII   -C UNICODE -b SINGLE     -u 36 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e UTF8  -c ASCII   -C UNICODE -b SINGLE     -u 37 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F DATA -e UTF8  -c ASCII   -C UNICODE -b SINGLE     -u 38 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e UTf8  -c ASCII   -C UNICODE -b SINGLE     -u 39 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
#metadata
 '-t TRANSPORT -p DB     -l START -m FILE -f DDL        -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 40 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f PAGES      -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 41 -v catalog -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 42 -v catalog -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 43 -v catalog -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 44 -v catalog -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I delete  -N localhost -R targetinstroot -D targetdb',                                                          
#data																			 
 '-t TRANSPORT -p DB     -l START -m FILE -f PAGES      -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 45 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p DB     -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 46 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 47 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f PAGES      -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 48 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f RECORDS    -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 49 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 50 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 51 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 52 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 53 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F DATA -e UTF8  -c UNICODE -C UNICODE -b SINGLE     -u 54 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f FORMATTED  -F FAST -e UTF8  -c UNICODE -C UNICODE -b SINGLE     -u 55 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F DATA -e UTF8  -c UNICODE -C UNICODE -b SINGLE     -u 56 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m FILE -f COMPRESSED -F FAST -e UTF8  -c UNICODE -C UNICODE -b SINGLE     -u 57 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
#metadata                                 usecases : ASCII2ASCII
 '-t TRANSPORT -p DB     -l START -m PIPE -f DDL        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 58 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
#data
 '-t TRANSPORT -p DB     -l START -m PIPE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 59 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p DB     -l START -m PIPE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 60 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 61 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f FORMATTED  -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 62 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f FORMATTED  -F FAST -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 63 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 64 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 65 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
#metadata                                 usecases : ASCII2UNICODE
 '-t TRANSPORT -p DB     -l START -m PIPE -f DDL        -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 66 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
#data
 '-t TRANSPORT -p DB     -l START -m PIPE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u 67 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p USER   -l START -m PIPE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u 68 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f RECORDS    -F DATA -e UCS2  -c ASCII   -C UNICODE -b SINGLE     -u 69 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f FORMATTED  -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 70 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f FORMATTED  -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 71 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F DATA -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 72 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F FAST -e ASCII -c ASCII   -C UNICODE -b SINGLE     -u 73 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
#metadata                                 usecases : UNICODE2UNICODE
 '-t TRANSPORT -p DB     -l START -m PIPE -f DDL        -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 74 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
#data
 '-t TRANSPORT -p DB     -l START -m PIPE -f PAGES      -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 75 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p DB     -l START -m PIPE -f RECORDS    -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 76 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f RECORDS    -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 77 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f FORMATTED  -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 78 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f FORMATTED  -F FAST -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 79 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F DATA -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 80 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F FAST -e UCS2  -c UNICODE -C UNICODE -b SINGLE     -u 81 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p TABLE  -l START -m PIPE -f COMPRESSED -F DATA -e UTF8  -c UNICODE -C UNICODE -b SINGLE     -u 82 -v all     -V none         -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I catalog -N localhost -R targetinstroot -D targetdb',                                                          
#metadata                                 usecases: ASCII2ASCII
 '-t TRANSPORT -p DB     -l START -m TAPE -f DDL        -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 83 -v catalog -V sorted       -z false -i catalog -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
#data
 '-t TRANSPORT -p DB     -l START -m TAPE -f PAGES      -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 84 -v all     -V sorted       -z false -i data    -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb',                                                          
 '-t TRANSPORT -p DB     -l START -m TAPE -f RECORDS    -F DATA -e ASCII -c ASCII   -C ASCII   -b SINGLE     -u 85 -v all     -V sorted       -z false -i delete  -n localhost -r sourceinstroot -d sourcedb  -I system  -N localhost -R targetinstroot -D targetdb'      

]

def _options ():
    return [
    #usecase
    ('u', 'usecase'                , ':', ''                    , 'specifies use    case'  ),                     
    ('v', 'validation'             , ':', ''                    , 'specifies validation scope'),                  # 
    ('V', 'validationmode'         , ':', ''                    , 'specifies validation type' ),                  # 
    ('z', 'debug'                  , ':', ''                    , 'specifies debug  mode'  ),                     # TRUE , FALSE
    #transport sourcedb to targetdb
    ('t', 'transformationtype'     , ':', ''                    , 'type      of transformation '),                # TRANSPORT, EXPORT, IMPORT
    ('p', 'transformationpackage'  , ':', ''                    , 'package   of transformation '),                # DB   , USER, TABLE, WEBDAV
    ('m', 'streammedium'           , ':', ''                    , 'streammedium of transformation '),             # PIPE , FILE, TAPE
    ('f', 'streamformat'           , ':', ''                    , 'streamformat of transformation '),             # RECORDS, PAGES, COMPRESSED, FORMATTED, FORMATTED BINARY, DDL, XML
    ('F', 'streamformat_target'    , ':', ''                    , 'streamformat of transformation '),             # DATA  , FAST
    ('e', 'streamcharencoding'    , ':', ''                     , 'streamcoding of transformation '),             # ASCII , UCS2, UTF8
    ('b', 'streamblob'             , ':', ''                    , 'blobmask     of transformation '),             # SINGLE, MULTIPLE
    ('l', 'restart'                , ':', ''                    , 'restart transformation '),                     # START , RESTART
    ('L', 'loaderinstroot'         , ':', os.environ['INSTROOT'], 'specifies sapdb  loader  independent path'),   # 
    #sourcedb
    ('i', 'sourceinit'             , ':', ''                    , 'init      sapdb  source'),                     # DELETE, SYSTEM, USER, CATALOG, DATA 
    ('c', 'sourcecharencoding'     , ':', ''                    , 'specifies sapdb  source char encoding '),      # ASCII , UNICODE
    ('n', 'sourcenode'             , ':', socket.gethostname()  , 'specifies source servernode'),
    ('r', 'sourceinstroot'         , ':', ''                    , 'specifies sapdb  source  instroot'), 
    ('j', 'sourceindepdatapath'    , ':', os.environ['INSTROOT'], 'specifies sapdb  source  independent path'), 
    ('d', 'sourcedbname'           , ':', ''                    , 'specifies source serverdb to create'),
    ('a', 'sourcedbauser'          , ':', 'DBA'                 , 'specifies source SYSDBA user'),
    #targetdb
    ('I', 'targetinit'             , ':', ''                    , 'init      sapdb  target'),                     # DELETE, SYSTEM, USER, CATALOG, DATA
    ('C', 'targetcharencoding'     , ':', ''                    , 'specifies sapdb  target char encoding '),      # ASCII , UNICODE
    ('N', 'targetnode'             , ':', socket.gethostname()  , 'specifies target servernode '),
    ('R', 'targetinstroot'         , ':', ''                    , 'specifies sapdb  target  instroot'), 
    ('J', 'targetindepdatapath'    , ':', os.environ['INSTROOT'], 'specifies sapdb  target  independent path'), 
    ('D', 'targetdbname'           , ':', ''                    , 'specifies target serverdb to create'),
    ('A', 'targetdbauser'          , ':', 'DBA'                 , 'specifies target SYSDBA user'),
] 

def check_knownbugs(options):
    rc = 0
    if (#medium file  
    
        # Usecases : UNICODE2UNICODE : -e UCS2 workaround : none
        #options.usecase       == 50,51,79    # PTS 1121536 Expecting NULL value, but found <?>.   
        #options.usecase       == 52,53       # E -25317, -25502: wrong NULL-value REPRESENTATION  
        options.usecase        == 78 or
        options.usecase        == 80 or       # E -25317 : wrong NULL-value REPRESENTATION : blocking test by mutex
        options.usecase        == 81 or       # E -25317 : wrong NULL-value REPRESENTATION : blocking test by mutex
        options.usecase        == 82 or       # Assertion failed: hlen > 0, file vls20.cpp, line 895
        #                              -e UTF8 
        #options.usecase       == 54,55       # E -25801,-25302,-25301,-25317,-25498
        #options.usecase       == 57          # E -25801
        options.usecase        == 38 or       # 
        options.usecase        == 56          #
        
        # Usecases : ASCII2UNICODE   : -e ASCII
        #options.usecase       == 32,33,34,35 # PTS 1121536 Expecting NULL value, but found <?>. 
        #options.usecase       == 34          # PTS 1121536 Expecting NULL value, but found <?>. , crash for -b multiple
                        
        # Usecases : ASCII2UNICODE   : -e UCS2 
        #options.usecase       == 71,73       # E -25801
        #                              -e UTF8 
        #options.usecase       == 36,37       # PTS 1122314 workaround: none -> usecase 32,38 or 33,39
        #options.usecase       == 38          # Expecting <2820> rows, but found <2819>.
        #options.usecase       == 39          # E -25801
        
        #options.usecase       == 20,48       # PTS 1122312 workaround : <owner>.<tablename>
        #options.usecase       == 22,23,43    # PTS 1121535 workaround : -b single
        
        #medium pipe
        
    ):
       print '\nERROR   usecase %s lets loader crash\n' % options.usecase
       rc = 1
    return rc

def main (options, args): 

    usecase = options.usecase
    
    for case in regsub.split(usecase,','):
        
        options.usecase = string.atoi(case,10)
        
        #source db
        if socket.gethostname() == 'p66796':
           options.sourceinstroot = os.path.join('D:','SAPDevelop','V743','usr') #'V7300','b_21',V743
        else:   
           options.sourceinstroot = os.path.join(os.environ['INSTROOT']) 
           
        #target db
        options.targetinstroot = os.path.join(os.environ['INSTROOT']) 
        options.loaderinstroot = os.path.join(os.environ['INSTROOT'])
        
        
        if  check_options(options) == 0 :

            #execute use case
            print '\n# %i: EXECUTE USECASE \n ' % (options.usecase)
            
            #usecase
            print '-u %i  ' % options.usecase
            print '-v %s  ' % options.validation
            print '-V %s  ' % options.validationmode
            print '-z %s\n' % options.debug
            
            #transformation attributes
            print '-t %s  ' % options.transformationtype
            print '-p %s  ' % options.transformationpackage
            print '-m %s  ' % options.streammedium
            print '-f %s  ' % options.streamformat
            print '-F %s  ' % options.streamformat_target
            print '-e %s  ' % options.streamcharencoding 
            print '-b %s  ' % options.streamblob
            print '-l %s\n' % options.restart
            
            #sourcedb
            print '-i %s  ' % options.sourceinit
            
            #targetdb
            print '-I %s\n' % options.targetinit
            
            #transformation resources
            init_transformation_resources(options)
            
            #transport sourcedb to targetdb
            print '\nTransport Source Database to Target Database'  
            
            #     |Loader Version  |Source Target Database |Transformation                            |Testframe  
            cmd = 'python %s -v %s -n %s -d %s -N %s -D %s  -p %s -m %s -f %s -F %s -e %s -b %s -l %s -u %s -z %s ' % ( os.path.join( os.environ ['JTEST_ROOT'],'loader','python','transport.py' ), options.loaderinstroot,
                                                                                                                        options.sourcenode, options.sourcedbname,  
                                                                                                                        options.targetnode, options.targetdbname,
                                                                                                                        options.transformationpackage, options.streammedium, options.streamformat, options.streamformat_target, options.streamcharencoding, options.streamblob, options.restart, 
                                                                                                                        options.usecase, options.debug )
            try:
               os.system (cmd)
            except OSError, err:
               print 'command failed:', err
               
            #transformation resources   
            deinit_transformation_resources(options) 
            
def init_transformation_resources (options):

    init_transformation_databases (options)
    init_transformation_files     (options)
    
def deinit_transformation_resources(options):
    
    deinit_transformation_files    (options)  
    
    #transformation attributes
    options.transformationpackage = ''
    options.streammedium          = ''   
    options.streamformat          = ''    
    options.streamformat_target   = ''    
    options.streamcharencoding   = ''    
    options.streamcoding_target   = ''    
    options.streamblob            = ''    
    options.restart               = ''    

    #sourcedb
    options.sourceinit            = ''
    options.transformationpackage = ''
    options.sourcecharencoding    = ''   
    options.sourcenode            = ''  
    options.sourceinstroot        = ''
    options.sourcedbname          = ''
    
    #targetdb   
    options.targetinit            = '' 
    options.targetcharencoding    = ''
    options.targetnode            = ''
    options.targetinstroot        = ''
    options.targetdbname          = ''          
    
def init_transformation_databases (options):
   
    try:
       if options.debug == 'TRUE':
          input('\nInit      Transformation Databases')
       if options.debug == 'FALSE':
          print '\nInit      Transformation Databases'
          i = 1/0
    except:
       pass 
          
    #sourcedb
    if options.sourceinit <> 'DELETE':
       print '\nInstall   Databasesystem %s ' % options.sourcedbname
       cmd = 'x_python %s -z %s -r %s -d %s -c %s ' % (os.path.join( os.environ ['JTEST_ROOT'],'loader','python','installdb.py' ) , options.debug,options.sourceinstroot,options.sourcedbname,options.sourcecharencoding)
# deactivated because Java test creates database
#       try:
#           os.system (cmd)
#       except OSError, err:
#           print 'command failed:', err
           
    try:
        session = dbm.DBM ('',options.sourcedbname, options.sourceinstroot, 'DBM,DBM' )
        sourceindepdatapath = session.cmd('dbm_getpath IndepDataPath ')
        options.sourceindepdatapath = regsub.split(sourceindepdatapath,'\n')[0]
    except dbm.CommunicationError, err :
        pass
        
    #db
    print '\nImport    Database       %s ' % options.sourcedbname
    cmd = 'x_python %s -z %s -r %s -d %s -i %s'    % (os.path.join( os.environ ['JTEST_ROOT'],'loader','python','demodb.py' )    , options.debug,options.targetinstroot,options.sourcedbname,options.sourceinit)
    try:
        os.system (cmd)
    except OSError, err:
        print 'command failed:', err    
        
    #targetdb
    if options.targetinit <> 'DELETE':
       print '\nInstall   Databasesystem %s \n'  % options.targetdbname 
       cmd = 'x_python %s -z %s -r %s -d %s -c %s ' % (os.path.join( os.environ ['JTEST_ROOT'],'loader','python','installdb.py' ) , options.debug,options.targetinstroot,options.targetdbname,options.targetcharencoding)
# deactivated because Java test creates database
#       try:
#           os.system (cmd)
#       except OSError, err:
#           print 'command failed:', err
           
    try:
        session = dbm.DBM ('',options.targetdbname, options.targetinstroot, 'DBM,DBM' )
        targetindepdatapath = session.cmd('dbm_getpath IndepDataPath ')
        options.targetindepdatapath = regsub.split(targetindepdatapath,'\n')[0]
    except dbm.CommunicationError, err :
        pass
        
    #db
    #init *registered* transformationpackage   
    if options.transformationpackage == 'WEBDAV':
       session = None 
       try:
           session = sql.connect ( options.targetdbauser, options.targetdbauser, options.targetdbname, options.targetnode ) 
       except sql.CommunicationError , err :
           print 'command failed:' , err
           
       #index
       cmd = 'DELETE FROM XML_ASSIGN_DC_IDX'
       try:    
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM XML_DOCUMENTCLASS'    
       try:        
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM XML_INDEXENGINE'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err    
       cmd = 'DELETE FROM XML_XMLINDEX'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM XML_INDEXINGSERVICEDESC'
       try:    
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM XML_SESSIONPOOL'    
       try:        
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM XML_INDEXINGLIB'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM XML_SEARCHLIB'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       #dav
       cmd = 'DELETE FROM WEBDAV_CONTAINER'
       try:    
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd ='DELETE FROM WEBDAV_INODE'
       try:    
           session.sql('DELETE FROM WEBDAV_INODE')
       except sql.SQLError, err :
           print 'command failed:' , err    
       cmd = 'DELETE FROM WEBDAV_NAME_SPACE'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM WEBDAV_PROPERTY'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       cmd = 'DELETE FROM WEBDAV_PROPERTY_MANAGEMENT'    
       try:                   
           session.sql(cmd)
       except sql.SQLError, err :
           print 'command failed:' , err
       
       session.commit () 
       session.release()

    print '\nImport    Database       %s '  % options.targetdbname 
    cmd = 'x_python %s -z %s -r %s -d %s -i %s'    % (os.path.join( os.environ ['JTEST_ROOT'],'loader','python','demodb.py' )    , options.debug, options.targetinstroot,options.targetdbname,options.targetinit)
    try:
        os.system (cmd)
    except OSError, err:
        print 'command failed:', err  
   
def init_transformation_files     (options): 
    try:
       if options.debug == 'TRUE':
          input('\nInit      Transformation Files')
       if options.debug == 'FALSE':
          print '\nInit      Transformation Files'
          i = 1/0
    except:
       pass 
       
    #source and target loader protocol file             
    try :
        os.chdir (os.path.join (options.targetindepdatapath, 'wrk'))

        curdir = os.getcwd()
        print 'Remove    Protocols %s' % curdir     
        for file in os.listdir(curdir) :
            if os.path.isfile(file) and  ( string.find(file,'loader') == 0 or string.find(file,'%s_loader' % options.usecase ) == 0 or string.find(file,'%s_install' % options.usecase ) == 0) :
               try:
                  os.unlink(file)
               except OSError, err:
                  print 'os.unlink (%s) failed: %s ' %( file ,err )

        os.mkdir(os.path.join(options.sourceindepdatapath, 'wrk', '%s' % options.sourcedbname, 'LOADER' ))
        os.mkdir(os.path.join(options.targetindepdatapath, 'wrk', '%s' % options.targetdbname, 'LOADER' ))
    except OSError, (errno, err ):
	if errno == 17 :
	   pass
	else:    
           print 'command failed %s ' % ( err )

    #source loader staging area                
    try :
        os.chdir (os.path.join(options.sourceindepdatapath,'wrk', '%s' % options.sourcedbname, 'LOADER' ))
    
        curdir = os.getcwd()
        print 'Empty     Directory %s' % curdir     
        for file in os.listdir(curdir) :
            if  file <> '%s.xml' % options.sourcedbname :
                try:
                    os.unlink(file)
                except OSError, err:
                    print 'os.unlink(%s) failed: %s ' % ( file , err  )
    except OSError, (errno, err ):
           print 'command failed %s ' % ( err )                
                
    #target loader staging area
    try :
        os.chdir (os.path.join(options.targetindepdatapath, 'wrk', '%s' % options.targetdbname, 'LOADER' ))
 
        curdir = os.getcwd()
        print 'Empty     Directory %s' % curdir     
        for file in os.listdir(curdir) :
            try:
                os.unlink(file)
            except OSError, err:
                print 'os.unlink (%s) failed: %s ' %( file, err  )
            
        #copy *registered* transformationpackage in source loader staging area
        if options.transformationpackage == 'WEBDAV':
           shutil.copy(os.path.join(options.targetinstroot,'env','WEBDAV.xml'), os.path.join(options.sourceindepdatapath, 'wrk', '%s' % options.sourcedbname, 'LOADER', '%s.xml' % options.sourcedbname ))
           
    except OSError, err:
           print 'command failed %s ' % ( err )                
               
    #backup file     
    try:
        os.mkdir     (os.path.join(options.sourceindepdatapath, 'wrk', '%s' % options.sourcedbname, 'TAPE' ))
        os.mkdir     (os.path.join(options.targetindepdatapath, 'wrk', '%s' % options.targetdbname, 'TAPE' ))  
    except OSError, (errno, err ):
	   if errno == 17 :
	      pass
	   else:    
 	      print 'os.mkdir (%s) failed: %s ' % (os.path.join(options.sourceindepdatapath, 'wrk', '%s' % options.sourcedbname, 'TAPE' ), err )

    if options.streammedium == 'TAPE' and socket.gethostname() == 'p66796':            
       try :
           os.chdir ("C:\\WINNT\\Temp\\")
       except OSError, err:
           print 'command failed:', err 
      
       curdir = os.getcwd() 
       print 'Empty     Directory %s' % curdir     
       for file in os.listdir(curdir) :
           if ( os.path.isfile(file) and ( 
                string.find(file,'temp')  == 0 )):
                try:
                    os.unlink(file)
                except OSError, err:
                    print 'command failed:', err 
                    
def deinit_transformation_files (options):
    # source db install protocol                  
    try :
        os.chdir (os.path.join (options.sourceinstroot, 'wrk'))
    except OSError, (errno, err ):
        print 'os.chdir %s : %s ' % (os.path.join (options.sourceinstroot, 'wrk'), err  )
    
    for file in os.listdir(os.curdir) :        
        if os.path.isfile(file) and  string.find(file,'install') == 0 :
           time.sleep(1) 
           file_install = string.replace(file, 'install', '%s_install' % options.usecase ) 
           try:
              os.rename(file,file_install)
           except OSError, err:
              print 'os.rename(%s) failed: %s ' % ( file , err )

    # target db install protocol                  
    try :
        os.chdir (os.path.join (options.targetinstroot, 'wrk'))
    except OSError, (errno, err ):
        print 'os.chdir %s : %s ' % (os.path.join (options.targetinstroot, 'wrk'), err  )
    
    for file in os.listdir(os.curdir) :        
        if os.path.isfile(file) and  string.find(file,'install') == 0 :
           time.sleep(1) 
           file_install = string.replace(file, 'install', '%s_install' % options.usecase ) 
           try:
              os.rename(file,file_install)
           except OSError, err:
              print 'os.rename(%s) failed: %s ' % ( file , err )
               
    try :
        os.chdir (os.path.join (options.targetindepdatapath, 'wrk'))
    except OSError, (errno, err ):
        print 'os.chdir %s : %s ' % (os.path.join (options.targetindepdatapath, 'wrk'), err  )
   
    for file in os.listdir(os.curdir) :
        #target loader protocol       
        if os.path.isfile(file) and  string.find(file,'loader_') == 0 :
           time.sleep(1) 
           file_target = string.replace(file, 'loader_', '%s_loader_' % options.usecase ) 
           try:
              os.rename(file,file_target)
           except OSError, err:
              print 'os.rename(%s) failed: %s ' % ( file , err )
        #source loader protocol              
        if os.path.isfile(file) and  string.find(file,'loader') == 0 :
           time.sleep(1) 
           file_source = string.replace(file, 'loader', '%s_loader' %  options.usecase ) 
           try:
              os.rename(file,file_source)
           except OSError, err:
              print 'os.rename(%s) failed: %s ' % ( file , err )
              
def check_parameter(options):
    rc = 0
    
    #transformation 
    if options.transformationtype    == '':
       options.transformationtype     = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [1] ,'t ',''),' ',''))  
    if options.transformationpackage == '':
       options.transformationpackage  = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [2] ,'p ',''),' ',''))
    if options.restart               == '':    
       options.restart                = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [3] ,'l ',''),' ',''))       
    #stream   
    if options.streammedium          == '':   
       options.streammedium           = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [4] ,'m ',''),' ',''))
    if options.streamformat          == '':    
       options.streamformat           = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [5] ,'f ',''),' ',''))
    if options.streamformat_target   == '':    
       options.streamformat_target    = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [6] ,'F ',''),' ',''))
    if options.streamcharencoding   == '':    
       options.streamcharencoding     = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [7] ,'e ',''),' ',''))
    if options.sourcecharencoding    == '':   
       options.sourcecharencoding     = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [8] ,'c ',''),' ',''))   
    if options.targetcharencoding    == '':
       options.targetcharencoding     = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [9] ,'C ',''),' ',''))
    if options.streamblob            == '':    
       options.streamblob             = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [10],'b ',''),' ',''))

    #usecase
    if options.usecase               == '':    
       options.usecase                = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [11],'u ',''),' ',''))
    if options.validation            == '':    
       options.validation             = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [12],'v ',''),' ',''))
    if options.validationmode        == '':    
       options.validationmode         = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [13],'V ',''),' ',''))      
    if options.debug                 == '':    
       options.debug                  = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [14],'z ',''),' ',''))
       
    #sourcedb
    if options.sourceinit            == '':
       options.sourceinit             = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [15],'i ',''),' ',''))
    else:
       options.sourceinit             = string.upper(options.sourceinit)
    if options.transformationpackage == 'WEBDAV' and options.sourceinit == 'DATA' :
       options.sourceinit             = 'WEBDAV'   
    if options.sourcenode            == '':  
       options.sourcenode             = socket.gethostname()
    if options.sourcedbname          == '':
       options.sourcedbname           = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [18],'d ',''),' ',''))
    
    #targetdb   
    if options.targetinit            == '': 
       options.targetinit             = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [19],'I ',''),' ',''))
    else:
       options.targetinit             = string.upper(options.targetinit)
    if options.targetnode            == '':
       options.targetnode             = socket.gethostname()
    if options.targetdbname          == '':
       options.targetdbname           = string.upper(string.replace(string.replace(regsub.split(parameters[options.usecase-1],'-') [22],'D ',''),' ',''))
    
    return rc   
              
              
def check_options(options):
    rc    = 0 
    if( check_range        (options) <> 0 or
        check_knownbugs    (options) <> 0 or
        check_parameter    (options) <> 0 or
        check_configuration(options) <> 0   ):
        rc = 1
    return rc            
           
def check_range    (options):
    rc = 0
    if options.usecase > 85:
       print 'Index out of range.' 
       rc = 1
    return rc  

def check_configuration (options):
    rc = 0
    if options.transformationpackage == 'WEBDAV':
       if socket.gethostname() == 'p66796' or socket.gethostname() == 'P48142':
          rc = 0
       else:        
          print 'Test for transformationpackage DAV only supported for servernode p66796 and P48142' 
          rc = 1
    if options.streammedium == 'TAPE' and socket.gethostname() <> 'p66796': 
       print 'Test for streammedium TAPE only supported for servernode p66796' 
       rc = 1
    if options.streammedium == 'PIPE' and sys.platform <> 'win32': 
       print 'Test for streammedium PIPE only supported for platform win32' 
       rc = 1
    return rc
       
if __name__ == '__main__':
   optlib.optMain2 (main, _options () )















































planned_testcases_1 = [
     #medium
     '-x false -p columns -m file      -f formatted  -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f formatted  -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f formatted  -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f formatted  -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f compressed -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f compressed -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f compressed -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p columns -m file      -f compressed -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     #medium
     '-x false -p db      -m pipe      -f pages              -i data    -c ascii -I system -C ascii   -e ascii -r start      -y sourceinstroot -d sourcedb -Y targetinstroot -D targetdb',  
     '-x false -p user    -m pipe      -f ddl        -e ascii          -r start    -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I user    -D targetdb',  
     '-x false -p user    -m pipe      -f pages      -e ascii          -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',  
     '-x false -p user    -m pipe      -f records    -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m pipe      -f ddl        -e ascii          -r start    -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb'
     '-x false -p table   -m pipe      -f pages      -e ascii          -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',  
     '-x false -p table   -m pipe      -f records    -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',
     #medium                                                                                
     '-x false -p db      -m tape      -f ddl        -e ascii          -r start    -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I system -D targetdb',   
     '-x false -p db      -m tape      -f records    -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system -D targetdb',   
     '-x false -p db      -m tape      -f pages      -e ascii          -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system -D targetdb',
     #medium
     '-x true  -p table   -m pipe2file -f records    -e ascii -F data  -r start    -y sourceinstroot -i delete   -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog  -D targetdb',       
     '-x true  -p table   -m pipe2file -f formatted  -e ascii -F data  -r start    -y sourceinstroot -i delete   -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog  -D targetdb',   
     '-x true  -p table   -m pipe2file -f compressed -e ascii -F data  -r start    -y sourceinstroot -i delete   -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog  -D targetdb'
]

planned_testcases_2 = [
     '-x false -p db      -m file      -f ddl        -e ascii          -r restart  -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I system -D targetdb',   
     '-x false -p db      -m file      -f pages      -e ascii          -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system -D targetdb',  
     '-x false -p db      -m file      -f records    -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system -D targetdb',   
     '-x false -p user    -m file      -f ddl        -e ascii          -r restart  -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I user    -D targetdb',  
     '-x false -p user    -m file      -f records    -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p user    -m file      -f pages      -e ascii          -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',  
     '-x false -p table   -m file      -f ddl        -e ascii          -r restart  -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',  
     '-x false -p table   -m file      -f pages      -e ascii          -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',  
     '-x false -p table   -m file      -f records    -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m file      -f formatted  -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m file      -f formatted  -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m file      -f compressed -e ascii -F data  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m file      -f compressed -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb', 
]

planned_usecases  = [
     '-x false -p db      -m file      -f xmi        -e ascii          -r restart  -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I system  -D targetdb',   
     '-x false -p db      -m file      -f xmi        -e ascii          -r start    -y sourceinstroot -i catalog  -c ascii -d sourcedb -C ascii -Y targetinstroot -I system  -D targetdb',   
     '-x false -p db      -m file      -f records    -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system  -D targetdb',   
     '-x false -p db      -m file      -f records    -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system  -D targetdb',   
     '-x false -p user    -m file      -f records    -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I user    -D targetdb',   
     '-x false -p user    -m file      -f records    -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I user    -D targetdb',   
     '-x false -p table   -m file      -f records    -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m file      -f records    -e ascii -F fast  -r restart  -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     #medium   
     '-x false -p db      -m pipe      -f records    -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I system  -D targetdb',   
     '-x false -p user    -m pipe      -f records    -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I user    -D targetdb',     
     '-x false -p table   -m pipe      -f records    -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m pipe      -f formatted  -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m pipe      -f formatted  -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m pipe      -f compressed -e ascii -F data  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
     '-x false -p table   -m pipe      -f compressed -e ascii -F fast  -r start    -y sourceinstroot -i data     -c ascii -d sourcedb -C ascii -Y targetinstroot -I catalog -D targetdb',   
]
