#!/usr/bin/perl
# @(#)sutparm       6.2.0   1996-02-09
#
#    ========== licence begin  GPL
#    Copyright (C) 2001 SAP AG
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#    ========== licence end
#

use Env;
use Getopt::Std;
use Carp;
use FileHandle;


# forces a flush after every write or print
$| = 1;

# printed to show activity
my $OneChar = ".";

my %SutParamOpts;
if (!getopts('hd:o:n:R:I:j:', \%SutParamOpts) || $SutParamOpts{h}) {
    print <DATA>;
    exit (1);
}

$ENV{JTEST_ROOT} = $SutParamOpts{j} if ($SutParamOpts{j});
$ENV{INSTROOT}   = $SutParamOpts{I} if ($SutParamOpts{I});

do "$ENV{JTEST_ROOT}/sut/sutvars.pl";

$serverdb = $SutParamOpts{d};
if ( $serverdb eq "" ) {
  print <DATA>;
  exit(1);
}

if ($SutParamOpts{o}) {
    $osuser = $SutParamOpts{o};
}


$SYSDEV = "SYSDEV";  
$ALOG   = "ARCHLOG"; 
$MLOG   = "M_ARCHLOG";
$DATA   = "DATADEV";

print "Anlegen des param-Files fuer den SUT\n";                

stop_db($serverdb, $StdColdUser);  
print $OneChar;

BInit($serverdb, $StdColdUser, $osuser, "OLTP"); 
print $OneChar;

#========================
# SIZE OF FRAME CONTROL =
#========================

PutParam($serverdb, "CACHE_SIZE", "810", undef);          print $OneChar;

#================================
# CONFIGURATION OF ARCHIVE LOGS =
#================================

PutParam($serverdb, "MAXARCHIVELOGS", "1", undef);            print $OneChar;
PutParam($serverdb, "ARCHIVE_SIZE_001", "900", undef);        print $OneChar;
PutParam($serverdb, "ARCHIVE_LOG_001",  "$ALOG", undef);      print $OneChar;

#=========================================
# NUMBER OF MERGE FILES FOR CREATE INDEX =
#=========================================

PutParam($serverdb, "_IDXFILE_LIST_SIZE", "128", undef);   print $OneChar;

#=========================================================
#=========================================================

PutParam($serverdb, "_MAXDEVSPACES", "4", undef);             print $OneChar;
PutParam($serverdb, "MAXDATADEVSPACES", "1", undef);          print $OneChar;
PutParam($serverdb, "LOG_SEGMENT_SIZE", "400", undef);        print $OneChar;
PutParam($serverdb, "LOG_IO_QUEUE", "16", undef);             print $OneChar;
PutParam($serverdb, "MAXBACKUPDEVS", "4", undef);             print $OneChar;
PutParam($serverdb, "MAXSERVERTASKS", "12", undef);           print $OneChar;
PutParam($serverdb, "MAXUSERTASKS", "2", undef);              print $OneChar;
PutParam($serverdb, "CAT_CACHE_SUPPLY", "96", undef);         print $OneChar;
PutParam($serverdb, "MAXLOCKS", "2500", undef);               print $OneChar;
PutParam($serverdb, "DEADLOCK_DETECTION", "0", undef);        print $OneChar;
PutParam($serverdb, "DATADEV_0001", "$DATA", undef);          print $OneChar;
PutParam($serverdb, "DATA_SIZE_0001", "3000", undef);         print $OneChar; # 2000-12-27 UH, set to 3000
PutParam($serverdb, "_CAT_CACHE_MINSIZE", "131072", undef); print $OneChar;
PutParam($serverdb, "REQUEST_TIMEOUT", "180", undef);      print $OneChar;
PutParam($serverdb, "LOG_IO_QUEUE", "17", undef);          print $OneChar;
PutParam($serverdb, "TRACE_PAGES_US", "450", undef);       print $OneChar;
if ($ENV{page32KB} eq "yes")
{
    PutParam($serverdb, "_PACKET_SIZE", "49152", undef);  print $OneChar;
    PutParam($serverdb, "_CAT_CACHE_MINSIZE", "262144", undef); print $OneChar;
}
else
{
    PutParam($serverdb, "_PACKET_SIZE", "32768", undef);  print $OneChar;
}
PutParam($serverdb, "SESSION_TIMEOUT", "420", undef);  print $OneChar;


BCheck($serverdb, $StdColdUser); print $OneChar;

print "\n";

__DATA__


 USAGE: sutinst [-h] [-n node -R remoteroot] [-d <serverdb>] [-o osuser,password]

        Creates a database for the single user tests

 OPTIONS:
       -h provides this help information
       -d specifies serverdb to create
       -n specifies the remote host serverdb to create on 
       -R specifies the dbroot directory on remote host
       -o specifies the operating system user and password (Unix only)





