#!/usr/bin/perl
# @(#) sutrun 
#
#    ========== licence begin  GPL
#    Copyright (C) 2001 SAP AG
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#    ========== licence end
#

use Env;
use File::Basename;
use File::Copy;
use Carp;
use Cwd;
use FileHandle;
use Getopt::Std;
&if $OS in [ UNIX ]
use IO::Handle;
&endif
&if $OS in [ WIN32 ]
use Win32::Registry;
use Win32::Process;
&endif
require "hostname.pl";

my $StartLetter = "A";

# forces a flush after every write or print
$| = 1;


my (%SutsingleOpts);
# option m is for future progression report and already used by jtest
usage() if (!getopts('hsav:d:n:R:j:I:c:m:', \%SutsingleOpts) || $SutsingleOpts{h});

if ( $SutsingleOpts{c} )
{
    if ($SutsingleOpts{c} =~ /^\s*dbuni\s*$/) {
        $ENV{DBUNICODE} = "y";
    }

    if ($SutsingleOpts{c} =~ /^\s*uni\s*$/) {
        $ENV{DBUNICODE} = "y";
        $ENV{DEFCODE}   = "UNICODE";
    }

    if ($SutsingleOpts{c} =~ /^\s*xci\s*$/) {
        $ENV{DBUNICODE} = "xci";
    }

    if ($SutsingleOpts{c} =~ /^\s*alluni\s*$/) {
        $ENV{DBUNICODE} = "xci";
        $ENV{DEFCODE}   = "UNICODE";
    }
}

$ENV{JTEST_ROOT} = $SutsingleOpts{j} if ($SutsingleOpts{j});
$ENV{INSTROOT}   = $SutsingleOpts{I} if ($SutsingleOpts{I});

do "$ENV{JTEST_ROOT}/sut/sutvars.pl";

usage("no database specified\n") if (!$SutsingleOpts{d});
$DBNAME = $SutsingleOpts{d};

usage("no version specified\n") if (!$SutsingleOpts{v});
my $VERSION = lc $SutsingleOpts{v};
my $PVERS   = substr($VERSION, 0, 1);

usage("'-a' option and teststream is ambiguously\n") 
    if  ( (@ARGV >= 1) and $SutsingleOpts{a});
    
usage("no teststream specified\n") if  ( (@ARGV < 1) and !($SutsingleOpts{a}));

my @TestList;
if ( $SutsingleOpts{a} ) {

    open(ISUT, "<$ENV{JTEST_ROOT}/sut/ISUT") || RuntimeError ( "can't open $ENV{JTEST_ROOT}/sut/ISUT\n");
    my @AllFiles = <ISUT>;
    close (ISUT);
    @AllFiles = sort map  { ($_) = /^D\d+\s+([^\s]*)/i; $_ .= ".vdnts" } @AllFiles;
    my @NormalFiles = grep  /^[$StartLetter-VZ].*\.vdnts/i && !/^VZLCTEST\.vdnts/i, @AllFiles;
    my @YFiles = grep  /^Y.*\.vdnts/i && !/^YINIT\.vdnts/i, @AllFiles;

    push @TestList, "XINITDB.vdnts"; 
    push @TestList, @NormalFiles;
    push @TestList, "YINIT.vdnts";
    push @TestList, @YFiles;

} else {
    @TestList = @ARGV;
}


usage("teststreams have to named with the extension '.vdnts'\n")
   if ( $TestList[$#TestList] !~ /.+\.vdnts/ );

$SutsingleOpts{s} ? ($stack_test=1) : undef $stack_test;


chdir("$ENV{JTEST_ROOT}/sut") || 
    RuntimeError ( "Can't change to directory $ENV{JTEST_ROOT}/sut: $!");

chomp ( local($local_host) = `hostname` );

$LEVEL = &GetConnectLevel();

# ermittle $ProtDir in Abhngigkeit von $VERSION, $DBUNICODE,
# $DEFCODE und $LEVEL

$ProtDir = $VERSION;
$ProtDir = "lvl_$LEVEL" if ( $LEVEL != 1 );
if ( $DBUNICODE )
{
  $ProtDir = "dbuni";
  $ProtDir = "uni"    if ( $DEFCODE   =~ /^unicode$/i );
  $ProtDir = "xci"    if ( $DBUNICODE =~ /^xci$/i );
  $ProtDir = "alluni" if ( ( $DBUNICODE =~ /^xci$/i ) && ( $DEFCODE   =~ /^unicode$/i ) );
}
$ProtDir = "stack" if $stack_test;
$ProtDir = "$ENV{JTEST_ROOT}/sut/$ProtDir";

$ENV{SERVERDB} = $DBNAME;

$DBBIGCMD ? ($Dbbigcmd=1) : ($Dbbigcmd=0);

stop_db($DBNAME, undef);

#   Ermittle ob die Variable DBUNICODE gesetzt ist
#   und setze danach den XPARAM Parameter. (not for Rel 6.1)

$DEF_CODE = "ASCII";

if ( ! $DBUNICODE )
{
    PutParam($DBNAME, "_UNICODE", "NO", undef);
    PutParam($DBNAME, "DEFAULT_CODE", "ASCII", undef);
}
else
{
    PutParam($DBNAME, "_UNICODE", "YES", undef);
    ( $DEFCODE eq "" ) ? ($DEF_CODE="ASCII") : ($DEF_CODE=$DEFCODE);
}

#   Ermittle den Namen des Protokolls durch Aufruf des Programmes
#   und auflisten der dadurch erzeugten Datei.

$CI_PROT = "ci.prt";

# Variablen fuer DBNAME
$RUNDIR  = GetParam( $DBNAME, "RUNDIRECTORY", undef);
$OPMSG3  = GetParam( $DBNAME, "_KERNELDIAGFILE", undef);
$KDUMP   = GetParam( $DBNAME, "_KERNELDUMPFILE", undef);
$KNLDIAG = GetParam( $DBNAME, "_KERNELDIAGFILE", undef);
$RDUMP   = GetParam( $DBNAME, "_RTEDUMPFILE", undef);

$dir = dirname($KNLDIAG);
if ( $dir eq "." or $dir eq ".." ) { $DIAG = "$RUNDIR/$KNLDIAG" } else { $DIAG = $KNLDIAG }
$dir = dirname($KDUMP);
if ( $dir eq "." or $dir eq ".." ) { $DUMP = "$RUNDIR/$KDUMP" } else { $DUMP = $KDUMP }
$dir = dirname($RDUMP);
if ( $dir eq "." or $dir eq ".." ) { $RDMP = "$RUNDIR/$RDUMP" } else { $RDMP = $RDUMP }



BCheck($DBNAME, $StdColdUser);

$DBHIF = $TERM;

print scalar localtime, "\n";
print " DBNAME  = $DBNAME";

print " \tProtDir = ".substr($ProtDir, length("$ENV{JTEST_ROOT}/sut/"))."\tPID: $$\n";

open(FILE_OUT, ">$AllCore"); close(FILE_OUT);
open(FILE_OUT, ">$AllDiff"); close(FILE_OUT);
open(FILE_OUT, ">$AllOk");   close(FILE_OUT);

#===================================================================
# Abarbeiten der Teststroeme
#===================================================================
# Die SUTs laufen mit einem vorgefertigten Paramfile

# transsize: 100 datasize: 400 code: ASCII archivesize: 200
install_paramfile( $DEF_CODE );

if ($SutsingleOpts{a}) {

    unlink (<$ProtDir/*.core>);
    unlink (<$ProtDir/*.dump>);
    unlink (<$ProtDir/*.rtedump>);
    unlink (<$ProtDir/*.prot>);
    unlink (<$ProtDir/*.pdiff>);
    unlink (<$ProtDir/*.vprot>);
    unlink (<$ProtDir/*.syserr>);

    open(FILE_OUT, ">>$AllSut");
    print FILE_OUT "--------------------------------------------------------\n";
    print FILE_OUT &Timestamp(1), "\tsutall $DBNAME $ProtDir\n";
    print FILE_OUT "--------------------------------------------------------\n";
    close(FILE_OUT);

}

foreach $TFN ( @TestList )
{

    $TFN =~ s/\.vdnts//i;

    if ( -f ".stop" ) { print "STOP request"; unlink(".stop" ); last }

    # fuer eine gleichmaessige Ausgabe in 'allsut'
    my $PTEST = $TFN." "x(14-length($TFN));

    if ( ! -f "$TFN.vdnts" )
    {
        open(FILE_OUT, ">>$AllSut");
        print FILE_OUT "NOT FOUND: $TFN.vdnts\n"; close(FILE_OUT);
        print "NOT FOUND: $TFN.vdnts\n";
        next;
    }

    # Ueberbleibsel des alten Testlaufs entfernen
    unlink <$RUNDIR/core*>, <*host*>, "shmcore", <*.HOST*>, $CI_PROT;
    unlink "$ProtDir/$TFN.core",  "$ProtDir/$TFN.dump", "$ProtDir/$TFN.rtedump";
    unlink "$ProtDir/$TFN.vprot", "$ProtDir/$TFN.prot", "$ProtDir/$TFN.pdiff";
    unlink "$ProtDir/$TFN.syserr";
    unlink "$ProtDir/$TFN.interrupt";
    unlink <$RMRUNDIR/cokernprotre*>;


    # Da einige Teststroeme ein spezielles Paramfile benoetigen
    # wird vor dem eigentlichen Lauf das entsprechende Paramfile
    # kopiert.

    CASE:
    {
        if ($TFN =~ /JOIN2TAB|LINKDDL|NIST3|USERTEST/i)
        {
            &install_paramfile( EBCDIC );
            last CASE;
        }
        if ($TFN =~ /STAV|STAU|UPDSTAT/i)
        {
            &install_paramfile( ASCII );
            last CASE;
        }
    } #CASE


    CASE:
    {
        if ( $TFN =~ /^Y.*/ ) { $RESTORE = "YRESTORE"; last CASE; }
        if ( $TFN =~ /^W.*/ ) { $RESTORE = "WRESTORE"; last CASE; }
        $RESTORE = "XRESTORE";
    }

    if ( $Dbbigcmd != 0 )
    {
        # Um groessere SQL Kommandos zu erhalten werden durch
        # das XCI Kommando "BIGCMD <offset>" Blanks vor jedes
        # SQL  Kommando geschrieben.
        open(FILE_OUT, ">>$RESTORE.cmd");
        print FILE_OUT "BIGCMD $DBBIGCMD !\n"; close(FILE_OUT);
    }
    if ( $DBUNICODE =~ /^xci/i )
    {
        if ( $DBLANG ne "" )
        {
            # Da der XCI hier garantiert nur Zeichen aus dem ASCII-Subset der
            # entsprechenden Kodierung schickt, wird ihm mit TERMINAL ASCII
            # mitgeteilt, dass er bei der Ausgabe von UNICODE-Spalten nur
            # halb soviel Platz benoetigt, wie der Kern ihm mitteilt.
            open(FILE_OUT, ">>$RESTORE.cmd");
            print FILE_OUT "TERMINAL ASCII!\n"; close(FILE_OUT);
        }
        else
        {
            # Diese Kombination der Umgebungsvariablen sagt aus, dass
            # der XCI die Auftragsschnittstelle als Unicode-Client
            # bedienen soll. Das wird ihm durch Aufruf des Kommandos
            # TERMINAL UNICODE am Anfang eines Testlaufs mitgeteilt.
            open(FILE_OUT, ">>$RESTORE.cmd");
            print FILE_OUT "TERMINAL UNICODE!\n"; close(FILE_OUT);
        }
    }

    print " $PVERS $LEVEL $PTEST ___ ";

    start_db($DBNAME, "-$VERSION", undef);

    print (scalar localtime);

    # create a watchdog process to avoid endless kernel loops 
    # default time for watchdog set to 30 minutes
    $MaxSutDuration = $ENV{MAXSUTDURATION} ? $ENV{MAXSUTDURATION} : 2400;
    
&IF $OS = WIN32
    Win32::Process::Create($Proc, "$PerlExe", "perl $ENV{JTEST_ROOT}\\sut\\killsut.pl -I $ENV{INSTROOT} -j $ENV{JTEST_ROOT} $DBNAME $ProtDir/$TFN.interrupt $MaxSutDuration", 
        1, CREATE_DEFAULT_ERROR_MODE, ".") || RuntimeError ( Win32::FormatMessage(Win32::GetLastError()));
&ELSE
    FORK: {
	    if ( $pid = fork() ) {
		    #parent
	    }
	    elsif ( defined($pid) ) {
		    # child
            sleep $MaxSutDuration ;
            system("echo > $ProtDir/$TFN.interrupt");
            stopdump_db($DBNAME) ;
            exit ; 
	    }
 	    else {
 		    #weird fork error
 		    RuntimeError ( "Can't fork: $!\n");
	    }
    }
&ENDIF

    system("$ENV{JTEST_ROOT}/sut/slowci -d $DBNAME -n $local_host -b $TFN.vdnts > $NULL");
    
    # get rid of watchdog 
&IF $OS = WIN32
    $Proc->Kill( 0 );
&ELSE
    kill 9, $pid; 
    waitpid $pid, 0;
&ENDIF
    
    stop_db($DBNAME, undef);

    system("echo > $RUNDIR/core_$TFN") if ( &DBCrash () );

    # Ausgabe der '...' zwischen 'slowci' und 'diff'
    print " ___ ";

    open(FILE_OUT, ">>$CI_PROT");
    print FILE_OUT " \n";  # .pibm have empty line beyond end
    close(FILE_OUT);


    # no stack test for remote sut
    if ( $stack_test )
    {

        system ( "$ENV{INSTROOT}/bin/xkernprot -d $DBNAME ax" );

        unlink "$ProtDir/$TFN.vprot", "$ProtDir/$TFN.s2", "$ProtDir/$TFN.s3", "$ProtDir/$TFN.sort";
        rename("$DBNAME.prt", "$ProtDir/$TFN.vprot");
        open(FILE_OUT, ">$ProtDir/$TFN.s2") || RuntimeError ( "Can't open $ProtDir/$TFN.s2(output): $!\n");
        open(FILE_IN, "$ProtDir/$TFN.vprot") || RuntimeError ( "Can't open $ProtDir/$TFN.vprot(input): $!\n");
        while(<FILE_IN>)
        {
             if ( /maxstack\s*:\s*(\d+)/ )
             {
                $help = $1;
                $i = $1;
                if ( length($help) eq 5 )
                {
                    $i = "0$1"
                }
                else
                {
                    if ( length($help) eq 4 )
                    {
                        $i = "00$1"
                    }
                }
                print FILE_OUT $i, " ", "$TFN:", $., "\n";
            }
        }
        close(FILE_IN); close(FILE_OUT);

        system("$SORT -o $ProtDir/$TFN.s3 -r $ProtDir/$TFN.s2");
        unlink "$ProtDir/$TFN.s2";

        open(FILE_IN, "$ProtDir/$TFN.s3") || RuntimeError ( "Can't open $ProtDir/$TFN.s3(input): $!\n");
        open(FILE_OUT, ">$ProtDir/$TFN.sort") || RuntimeError ( "Can't open $ProtDir/$TFN.sort(output): $!\n");
        while(<FILE_IN>)
        {
            if (41..eof()) { next }
            print FILE_OUT $_ ;
        }
        close(FILE_IN); close(FILE_OUT);
        unlink "$ProtDir/$TFN.s3";
        unlink "$ProtDir/$TFN.s2";

        @ARGV = ( $CI_PROT );
        do "$ENV{JTEST_ROOT}/sut/sed_stack.pl";
        if ( $@ ) { RuntimeError ( "Error while executing sed_stack:\n", "$@"); }

    }

    # Zuruecksetzen des Paramfiles
    &install_paramfile( $DEF_CODE );

    #  Absturz des lokalen DB-Kerns:
    @CORE = <$RUNDIR/core*>;
    if (@CORE) {

        open(FILE_OUT, ">>$AllSut");
        print FILE_OUT &Timestamp(1), "\t$PVERS $LEVEL $PTEST core$local\n"; close(FILE_OUT);
        open(FILE_OUT, ">>$AllCore");
        print FILE_OUT "$TFN.prot\n"; close(FILE_OUT);
        open(FILE_OUT, ">>$CI_PROT");
        print FILE_OUT "$TFN\n"; 


        if  ( -r $DIAG ) {
            print FILE_OUT "save $DIAG\n";
            open(DIAG, "$DIAG");
            while(<DIAG>) { print FILE_OUT $_ unless /^\s+$/ }
            close(DIAG);
        }
        close(FILE_OUT);

        if ( ! $DELSUTCORE ) {

           unlink "$ProtDir/$TFN.core", "$ProtDir/$TFN.dump", "$ProtDir/$TFN.rtedump";
           system("echo > $ProtDir/$TFN.core");
           rename($DUMP, "$ProtDir/$TFN.dump");
           rename($RDMP, "$ProtDir/$TFN.rtedump");
           
        } else {
        
           unlink $CORE, $DUMP, $RDMP; 
           system("echo > $ProtDir/$TFN.core");
           system("echo > $ProtDir/$TFN.dump");
           system("echo > $ProtDir/$TFN.rtedump");
        }

        # im Absturzfall VTRACE ziehen
        system ( "$ENV{INSTROOT}/bin/xkernprot -d $DBNAME akbx > $NULL" );
        unlink ("$ProtDir/$TFN.vprot");
        rename("$DBNAME.prt", "$ProtDir/$TFN.vprot");

    } 

    # save some files to have a chance to analyze reason for 
    # never ending sut if not already done by core handling
    if  ( (-f "$ProtDir/$TFN.interrupt") && (0 == @CORE) ) {
        
        # knldiag
        if  ( -r $DIAG ) {
            open(FILE_OUT, ">>$CI_PROT");
            print FILE_OUT "save $DIAG\n";
            open(DIAG, "$DIAG");
            while(<DIAG>) { print FILE_OUT $_ unless /^\s+$/ }
            close(DIAG);
            close(FILE_OUT);
        }
        
        # vtrace 
        system ( "$ENV{INSTROOT}/bin/xkernprot -d $DBNAME akbx > $NULL" );
        unlink ("$ProtDir/$TFN.vprot");
        rename("$DBNAME.prt", "$ProtDir/$TFN.vprot");
       
        # dump
        rename($DUMP, "$ProtDir/$TFN.dump") if ( -e "$DUMP" );

        # rtedump
        rename($RDMP, "$ProtDir/$TFN.rtedump") if ( -e "$RDMP" );
    } 


    if ( ($Dbbigcmd != 0) or $DBUPDSTAT or ($DBUNICODE =~ /^xci/i) ) {
        # jetzt wrid das XCI Kommando "BIGCMD <offset>"
        # wieder entfernt
        unlink "$RESTORE.tmp";
        rename("$RESTORE.cmd", "$RESTORE.tmp") || warn "Can't rename $RESTORE.cmd to $RESTORE.tmp: $!";
        open(FILE_IN, "<$RESTORE.tmp" ); open(FILE_OUT, ">$RESTORE.cmd" );
        while(<FILE_IN>) {
            next if /^(BIGCMD|TERMINAL|UPDSTAT ON)/;
            next if /UPDSTAT ON/;
            s/\* if rc/if rc/;
            print FILE_OUT $_;
        }
        close(FILE_IN); close(FILE_OUT);
        unlink  "$RESTORE.tmp";
    }


    #===============================================================
    #-------jetzt wird das Protokoll so verbogen, dass moeglichst viele
    #   der laestigen 'ewigen' Differenzen wegfallen (Datum, Zeit, ...)
    #===============================================================

    # We do this in a subshell to leave DBNAME undisturbed...
    @ARGV = ( "$CI_PROT", "$TMPDIR/$TFN.prot" );
    do "$ENV{JTEST_ROOT}/sut/sed_sut.pl";
    if ( $@ ) { RuntimeError ( "Error while executing sed_sut:\n", "$@"); }

    if  ( $LEVEL != 1 )
    {
        #  Aendern des Isolation-Levels auf 1; der urspruengliche I.L.
        #  ist nur noch anhand der Zeit der letzten Aenderung bzw. an
        #  der Directory, in der das Protokoll steht, zu erkennen.
        #  Diese Loesung war leider noetig, da 'diff' kein 'ignore'
        #  kennt.
        @ARGV = ( "$LEVEL", "$TMPDIR/$TFN.prot" );
        do "$ENV{JTEST_ROOT}/sut/sed_sut_lvl.pl";
        if ( $@ ) { RuntimeError ( "Error while executing sed_sut_lvl:\n", "$@"); }
    }

    if ( $DBUNICODE )
    {
        # Aendern der Ausgaben, die aufgrund der nur 9 Byte langen
        # Identifier im 'UNICODE'-Lauf anders sind als im normalen
        # Lauf
        @ARGV = ( "$TMPDIR/$TFN.prot" );
        do "$ENV{JTEST_ROOT}/sut/sed_sut_uni.pl";
        if ( $@ ) { RuntimeError ( "Error while executing sed_sut_uni:\n", "$@"); }
    }


    #unlink $CI_PROT;

    # Die Fehlerpositionen werden aus dem Protokoll entfernt.
    if ( $Dbbigcmd )
    {
        @ARGC = ( "$TMPDIR/$TFN.prot", "$TMPDIR/PROT" );
        do "$ENV{JTEST_ROOT}/sut/sed_term.pl";
        if ( $@ ) { RuntimeError ( "Error while executing sed_term:\n", "$@"); }
    }

    #   echo "analyze differences"

    $DIFFEXT = "punix";
    if ( $VERSION =~ /fast|quick/ ) { 
       if ( -s "$TFN.tpunx" ) { $DIFFEXT = "tpunx" } 
    }

    if ( $DBUNICODE =~ /^xci/i and  
         $DBLANG eq "" and 
         $DEF_CODE eq UNICODE and 
         -s "$TFN.cpnix" )
    {
        # Unicode-Auftragsschnittstelle mit eigenem Referenzprotokoll...
        $DIFFEXT = "cpnix";
    }
    else
    {
       if ( $DBUNICODE =~ /^xci/i and  $DBLANG eq "" and -s "$TFN.cunix" )
       {
           # Unicode-Auftragsschnittstelle mit eigenem Referenzprotokoll...
           $DIFFEXT = "cunix";
       }
       else
       {
           if ( $DBUNICODE )
           {
               if ( $DEF_CODE eq UNICODE )
               {
                   if         ( -s "$TFN.upnix" ) { $DIFFEXT = "upnix" }
                   else { if  ( -s "$TFN.uunix" ) { $DIFFEXT = "uunix" } }
               }
               else { if  ( -s "$TFN.uunix" ) { $DIFFEXT = "uunix" } }
           }
       }
    }

    if  ( -s "$TFN.$DIFFEXT" )
    {
        $DIFFRC = 0;
        if ( $Dbbigcmd )
        {
            @ARGV = ( "$TFN.$DIFFEXT", "$TMPDIR/PUNIX" );
            do "$ENV{JTEST_ROOT}/sut/sed_term.pl";
            if ( $@ ) { RuntimeError ( "Error while executing sed_term:\n", "$@"); }
            system("$DIFF $TMPDIR/PUNIX $TMPDIR/PROT > $ProtDir/$TFN.pdiff");
            $DIFFRC = $?;
            unlink "$TMPDIR/PUNIX", "$TMPDIR/PROT";
        }
        else
        {
            $DIFFRC = system("$DIFF $TFN.$DIFFEXT $TMPDIR/$TFN.prot > $ProtDir/$TFN.pdiff");
        }
        if ( $DIFFRC == 2 )
        {
            open(FILE_OUT, ">>$ProtDir/$TFN.pdiff");
            print FILE_OUT "DIFF-ERROR HAPPENED\n";
        }
        elsif ( $DIFFRC != 0 )
        {
            $pdiff = "$ProtDir/$TFN.pdiff";
&IF $OS <> WIN32
            &runStdUndiff ('STDDIFF.diffscr', $pdiff);
&ENDIF
            if (-s $pdiff) {
                &runStdUndiff ("$TFN.diffscr", $pdiff);
            }
        }
    }
    else
    {
        open(FILE_OUT, ">$ProtDir/$TFN.pdiff");
        # kein Protokoll zum Vergleichen da !
        print FILE_OUT "new test without protocol: $TFN\n";
    }

    close(FILE_OUT);
    if ( $DIFFEXT =~ /punix|tpunx/) { $DIFFEXT = "" }

    if  ( -f "$ProtDir/$TFN.interrupt" ) {
        $Interrupted = "interrupted";
    } else {
        $Interrupted = " ";
    }
    
    if  ( -s "$ProtDir/$TFN.pdiff" )
    {
        open(DIFF_FILE,"<$ProtDir/$TFN.pdiff"); 
        while (<DIFF_FILE>) {
            if ( $_ =~ />.*ERROR\s*(-9\d{3}|-602)/ ) {
                system("echo > $ProtDir/$TFN.syserr");
            }
        }
        close (DIFF_FILE);
        
        
        $CHARS = `wc -c < $ProtDir/$TFN.pdiff`; chomp $CHARS;
        open(FILE_OUT, ">>$AllSut");
        print FILE_OUT &Timestamp(1), "\t$PVERS $LEVEL $PTEST * $CHARS $DIFFEXT $Interrupted\n";
        if ( -f "$ProtDir/$TFN.core" ) { print "core\n"; }
        else
        {
           print "diff  $CHARS characters $Interrupted\n";
        }

        open(FILE_OUT, ">>$AllDiff");
        print FILE_OUT "$TFN.pdiff $Interrupted", "\n";
        unlink "$ProtDir/$TFN.prot";
        rename("$TMPDIR/$TFN.prot", "$ProtDir/$TFN.prot") || warn "Can't rename $TMPDIR/$TFN.prot to $ProtDir/$TFN.prot: $!";
    }
    else
    {
        open(FILE_OUT, ">>$AllSut");
        print FILE_OUT &Timestamp(1), "\t$PVERS $LEVEL $PTEST $DIFFEXT $Interrupted\n";
        if ( -f "$ProtDir/$TFN.core" )
        {
             print "core $Interrupted\n"
        }
        else { print "ok $Interrupted\n" }

        open(FILE_OUT, ">>$AllOk");
        print FILE_OUT &Timestamp(1), "\t$PVERS $LEVEL $PTEST $Interrupted";
        unlink "$ProtDir/$TFN.pdiff", "$TMPDIR/$TFN.prot";
    }
    

    if ( ($TFN =~ /VZLCTEST/i) )
    {
        PutParam($DBNAME, "INSTANCE_TYPE", "OLTP", undef);
    }


    # check if save exists after xinitdb                      
    if ($TFN =~ /XINITDB/i) {
        unless  (-f "$RUNDIR/xinitdb.sav") {
            print "no save after XINITDB -> exit sutrun\n";
            exit -1;
        }
    }

} #while



undef($SUTOPTION);
close(FILE_OUT);

opendir(DIR, "$ProtDir");
my @PdiffFiles = grep /\.pdiff$/, readdir(DIR);
closedir(DIR);

exit scalar @PdiffFiles if ( @PdiffFiles );

exit 0;

##################################################################
sub usage {
    my $str = shift;
    print $str;
    print "usage: sutsingle [-j <jtestroot>] [-I <instroot>]\n";
    print "                 [-c dbuni|uni|xci|alluni]\n";
    print "                 -d dbname -v fast|quick|slow\n";
    print "                 -a <startletter>  | teststream.vdnts ... \n";
    exit 1;
}

##################################################################
sub install_paramfile {

   PutParam($DBNAME, "DEFAULT_CODE", $_[0], undef);

}

##################################################################
sub DBCrash ()
{
    return GetParam( $DBNAME, "_DIAG_SEM", undef);
}

#####################################################
sub runStdUndiff () {

    my ($diffScript, $protFile) = @_;

    if (-r $diffScript)
    {
        $scriptRC = system("$PythonExe $diffScript $protFile");
        if ($scriptRC != 0)
        {
            open PDIFF, ">>$protFile";
            print PDIFF "script ($diffScript, $protFile) failed with $scriptRC";
            close PDIFF;
        }
    }
}


#####################################################
sub Timestamp () {
    
    my $no_linefeed = shift;
    local($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime(time);
	$year = $year - 100 if ( $year > 99 ); # PTS 1105199
	$mon++; # adapt month
    foreach ( "mon", "mday", "hour", "min", "sec" ) 
    {
	    $$_ = "0$$_" if length($$_) == 1;
    }
    my $timestamp = "$year-$mon-$mday-$hour.$min.$sec";
	$timestamp="0".$timestamp if ( $year < 10 );  # PTS 1105199
    $timestamp .= "\n" unless $no_linefeed;
    return($timestamp);
}


#####################################################
sub GetConnectLevel () {
    
    my $fh; 
    local $rc;
    if ( $fh = new FileHandle "CONNECT.cmd", "r" )
    {
        while(<$fh>) 
        {
            if ( /^CONNECT &1 IDENTIFIED BY &2 &3 &4 ISOLATION LEVEL (\d+).*/i ) 
            {
                $rc = $1; last;
            }
        }
        $fh->close;
    }
    return $rc;
}

#####################################################
sub RuntimeError () {
    my ($ErrorTxt) = join ' ', @_;
    my ($package, $filename, $line) = caller();
    print "\nruntime error in $filename\:\:$package in line $line\: ", $ErrorTxt;
    exit -1
}
    
__END__

