#!/usr/bin/perl
#
# @(#) sutvars			1997-11-18
#
# constants for all sutscripts
#
#
#    ========== licence begin  GPL
#    Copyright (C) 2001 SAP AG
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#    ========== licence end
#

use Env;
use Carp;


# Protokollverzeichnise anlegen
&if $OSSPEC = WIN32
$PERM = 0;
&else
$PERM = 0775;
&endif

mkdir("$ENV{JTEST_ROOT}/sut/fast", $PERM)       unless -d "$ENV{JTEST_ROOT}/sut/fast";
mkdir("$ENV{JTEST_ROOT}/sut/slow", $PERM)       unless -d "$ENV{JTEST_ROOT}/sut/slow";
mkdir("$ENV{JTEST_ROOT}/sut/quick", $PERM)      unless -d "$ENV{JTEST_ROOT}/sut/quick";
mkdir("$ENV{JTEST_ROOT}/sut/uni", $PERM)        unless -d "$ENV{JTEST_ROOT}/sut/uni";
mkdir("$ENV{JTEST_ROOT}/sut/dbuni", $PERM)      unless -d "$ENV{JTEST_ROOT}/sut/dbuni";
mkdir("$ENV{JTEST_ROOT}/sut/xci", $PERM)        unless -d "$ENV{JTEST_ROOT}/sut/xci";
mkdir("$ENV{JTEST_ROOT}/sut/alluni", $PERM)     unless -d "$ENV{JTEST_ROOT}/sut/alluni";
mkdir("$ENV{JTEST_ROOT}/sut/lvl_0", $PERM)      unless -d "$ENV{JTEST_ROOT}/sut/lvl_0";
mkdir("$ENV{JTEST_ROOT}/sut/lvl_2", $PERM)      unless -d "$ENV{JTEST_ROOT}/sut/lvl_2";
mkdir("$ENV{JTEST_ROOT}/sut/lvl_3", $PERM)      unless -d "$ENV{JTEST_ROOT}/sut/lvl_3";
mkdir("$ENV{JTEST_ROOT}/sut/lvl_15", $PERM)     unless -d "$ENV{JTEST_ROOT}/sut/lvl_15";
mkdir("$ENV{JTEST_ROOT}/sut/stack", $PERM)      unless -d "$ENV{JTEST_ROOT}/sut/stack";
mkdir("$ENV{JTEST_ROOT}/sut/stack-save", $PERM) unless -d "$ENV{JTEST_ROOT}/sut/stack-save";
mkdir("$ENV{JTEST_ROOT}/sut/prot", $PERM)       unless -d "$ENV{JTEST_ROOT}/sut/prot";
mkdir("$ENV{JTEST_ROOT}/sut/tmp", $PERM)        unless -d "$ENV{JTEST_ROOT}/sut/tmp";

# zusammenfassende Protokolle
$AllSut  = "$ENV{JTEST_ROOT}/sut/prot/allsut.prt";
$AllCore = "$ENV{JTEST_ROOT}/sut/prot/allcore.prt";
$AllDiff = "$ENV{JTEST_ROOT}/sut/prot/alldiff.prt";
$AllOk   = "$ENV{JTEST_ROOT}/sut/prot/allok.prt";
$AllTest = "$ENV{JTEST_ROOT}/sut/prot/alltest.prt";
$AllStack= "$ENV{JTEST_ROOT}/sut/prot/allstack.prt";

$StdColdUser="superdba,colduser";


# SUT-globale Makros
$TMPDIR = "$ENV{JTEST_ROOT}/sut/tmp/";
&if $OS = WIN32
$NULL = "nul";
$PROG_EXT = ".exe";
$X_DIAGNOSE = "x_diag.exe";
$DIFF       = "diff -bw";
$SORT       = "sort";
$PerlExe    = "$ENV{PERL}/bin/perl.exe";
$PythonExe  = "$ENV{PYTHON}/python.exe";
$DBMCLIExe  = "$ENV{INSTROOT}/pgm/dbmcli.exe";
&else
$PROG_EXT = "";
$NULL = "/dev/null";
$X_DIAGNOSE = "x_diagnose";
$DIFF = "diff -bw";
$SORT = "sort";
$PerlExe    = "$ENV{PERL}/bin/perl";
$PythonExe  = "$ENV{PYTHON}/python";
$DBMCLIExe  = "$ENV{INSTROOT}/bin/dbmcli";
&endif

##################################################################
sub start_db
{
  my $db = shift;
  my $dbvers = shift;
  my $user = shift;
  
  $user = $StdColdUser if !defined($user);
  system("$DBMCLIExe -d $db -u $user db_clear > $NULL");
  DBMRetryCmd("$DBMCLIExe -d $db -u $user start $dbvers > $NULL");
  
}

##################################################################
sub stopdump_db
{
  my $db         = shift;
  my $user       = shift;
  
  $user = $StdColdUser if !defined($user);
  
  system("$DBMCLIExe -d $db -u $user db_stop -dump >$NULL 2>&1");

}

##################################################################
sub stop_db
{
  my $db   = shift;
  my $user = shift;
  
  $user = $StdColdUser if !defined($user);
  system("$DBMCLIExe -d $db -u $user stop >$NULL 2>&1");

}

#################################################################
sub PutParam
{
    my ($Database, $Variable, $Value, $user) = @_;
    
    $user = $StdColdUser if !defined($user);
    system("$DBMCLIExe -d $Database -u $user param_directput $Variable $Value") == 0
	 or croak "Error while executing param_directput";
    
}


#################################################################
sub GetParam
{
    my ($Database, $Variable, $user) = @_;
    local ($Value, $Status);
    $user = $StdColdUser if !defined($user);
    open(PIPE_IN, "$DBMCLIExe -d $Database -u $user param_directget $Variable |") ||
        croak "Error while executing \"dbmcli -d $Database -u $user param_directget $Variable\"\n".
        "message: $!\n";
    chomp($Status = <PIPE_IN>);
    chomp($Value = <PIPE_IN>);
    close(PIPE_IN);
    die "Can't get parameter $Variable!\n$Value\n" if $Status !~ /OK/;
    ($Value) = $Value =~ /.+\s+(.*)/;
    return $Value;
}


#################################################################
sub BCheck
{
    my ($Database, $user) = @_;

	local $fh = new FileHandle;
	if ( ! $fh->open("Check_Param.dat", "w") )
	{
	    die "Can't open Check_Param.dat (output) :$!\n";
	}
	else
	{
	    $fh->print("param_startsession\n");
	    $fh->print("param_checkall\n");
	    $fh->print("param_commitsession\n");
	}
	$fh->close;

    system("$DBMCLIExe -d $Database -u $user -i Check_Param.dat") == 0
        or croak "Error while executing BCHECK";

    unlink ("Check_Param.dat");

}

#################################################################
sub BInit
{
    my ($Database, $user, $osuser, $instance) = @_;

	local $fh = new FileHandle;


    # drop db
    system("$DBMCLIExe -d $Database -u $user db_drop");

    # create db
	my $rc;
	if (defined $osuser) {
	    DBMRetryCmd ("$DBMCLIExe -R $INSTROOT db_create $Database $user $osuser");
	} else {
	    DBMRetryCmd ("$DBMCLIExe -s -R $INSTROOT db_create $Database $user");
	}
    
    # create new PARAM file
	if ( ! $fh->open("Init_Param.dat", "w") )
	{
	    die "Can't open Init_Param.dat (output) :$!\n";
	}
	else
	{
	    $fh->print("param_startsession\n");
   	    $fh->print("param_init $instance\n");
	    $fh->print("param_checkall\n");
	    $fh->print("param_commitsession\n");
	}
	$fh->close;
    system("$DBMCLIExe -d $Database -u $user -i Init_Param.dat") == 0
        or croak "Error while executing init_param";

	unlink ("Init_Param.dat");

    # at win32 systems register other kernel versions
	if ( $^O =~ /mswin32/i) {
        if ( -f "$ENV{INSTROOT}/pgm/quickknl.exe" ) {
            DBMRetryCmd("$DBMCLIExe -d $Database -u $user db_register -quick");
        }
        if ( -f "$ENV{INSTROOT}/pgm/slowknl.exe" ) {
            DBMRetryCmd("$DBMCLIExe -d $Database -u $user db_register -slow");
        }
     }

}

#################################################################
sub DBMRetryCmd ()
{
    my ($cmd) = @_;

    system("$cmd") == 0
        or system("$cmd") == 0
        or system("$cmd") == 0
        or croak "Error while executing \"$cmd\"\n";
}



1;
